<?php

namespace backend\modules\master\controllers;

use Yii;
use backend\modules\master\models\AccountingTax;
use backend\modules\master\models\AccountingTaxSearch;
use backend\modules\master\models\AccountingLedger;
use backend\modules\master\models\AccountType;
use backend\modules\master\models\Taxtype;
use yii\data\ActiveDataProvider;
use yii\helpers\ArrayHelper;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * AccountingTaxController implements the CRUD actions for AccountingTax model.
 */
class AccountingTaxController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }
    // public static $tax_type=["Service Tax"=>"Service Tax",
    // "VAT Tax"=>"VAT Tax",
    // "TDS"=>"TDS",
    // "ED"=>"ED",
    // "CESS"=>"CESS",
    // "Import/Export"=>"Import/Export",
    // "Custom Tax"=>"Custom Tax",
    // "CGST"=>"CGST",
    // "SGST"=>"SGST",
    // "IGST"=>"IGST",
    // ];
    /**
     * Lists all AccountingTax models.
     * @return mixed
     */
    public function actionIndex()
    {
        Yii::$app->view->params['active']=3;
        $model = new AccountingTax();
        $searchModel = new AccountingTaxSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            // 'taxes'=>AccountingTaxController::$tax_type,

        ]);
    }

    /**
     * Displays a single AccountingTax model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new AccountingTax model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        Yii::$app->view->params['active']=3;

        $model = new AccountingTax();
        $taxes=Taxtype::find()->all();
        $taxtype_list=ArrayHelper::map($taxes, 'tax_type_name', 'tax_type_name');
        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            if($model->status==NULL){
                $model->status=1;
                $model->save();
            }
            Yii::$app->getSession()->setFlash('success', 'Created Successfully');
            return $this->redirect(['index']);
        }

        return $this->render('_form', [
            'model' => $model,
            'taxtype_list'=>$taxtype_list,
            // 'taxes'=>AccountingTaxController::$tax_type,
            'update'=>0,
        ]);
    }
    
    /**
     * Updates an existing AccountingTax model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        Yii::$app->view->params['active']=3;
        $model = $this->findModel($id);
        $taxes=Taxtype::find()->all();
        $taxtype_list=ArrayHelper::map($taxes, 'tax_type_name', 'tax_type_name');
        if($model->is_deleted)
        throw new NotFoundHttpException('The requested page does not exist.');
        $data=AccountingTax::find()->where(['accounting_tax_id'=>$id,'is_deleted'=>0])->all();
        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            if($model->status==NULL){
                $model->status=1;
                $model->save();
            }
            Yii::$app->getSession()->setFlash('success', 'Updated Successfully');
            return $this->redirect(['index']);
        }

        return $this->render('_form', [
            'model' => $model,
            // 'taxes'=>AccountingTaxController::$tax_type,
            'update'=>1,
            'taxtype_list'=>$taxtype_list,
            'data'=>$data,

        ]);
    }
    public function actionGetLedgers()
    {
        $account=AccountingLedger::find()->all();
        $accountlist=ArrayHelper::map($account, 'ledger_id', 'ledger_id');
        $accountlist=[];
        foreach($account as $value){
            $accounttype=AccountType::find()->where(['account_type_id'=>$value->account_type_id])->one();
            $accountlist[$accounttype['account_name']][$value->ledger_id]=$value->ledger_id;
        }
        print_r(json_encode($accountlist));die();
        return json_encode($accountlist);
    }

    /**
     * Deletes an existing AccountingTax model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id=null)
    {
        Yii::$app->view->params['active']=3;
        if($id==null)
        {
            $ids=Yii::$app->request->post('data');
            foreach($ids as $id){
                $tax=$this->findModel($id);  
                $tax->is_deleted =1;
                $tax->save(false);
            }
            Yii::$app->getSession()->setFlash('success', 'Deleted Successfully');
            return $this->redirect(['index']);
        }
        else
        {
            $tax=$this->findModel($id);  
            $tax->is_deleted =1;
            $tax->save(false);
            Yii::$app->getSession()->setFlash('success', 'Successfully Deleted');
            return $this->redirect(['index']);
        }       
    }
    /**
     * Finds the AccountingTax model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return AccountingTax the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = AccountingTax::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
