<?php

namespace backend\modules\master\controllers;

use Yii;
use backend\modules\master\models\BusinessType;
use backend\modules\master\models\BusinessTypeSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use Mpdf\Mpdf;
use yii\data\ActiveDataProvider;
use yii2tech\spreadsheet\Spreadsheet;
/**
 * BusinessTypeController implements the CRUD actions for BusinessType model.
 */
class BusinessTypeController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    // 'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all BusinessType models.
     * @return mixed
     */
    public function actionIndex()
    {
        Yii::$app->view->params['active']=9;
        $model = new BusinessType();
        $searchModel = new BusinessTypeSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

         if ($model->load(Yii::$app->request->post()) ) {

             $model->created_at=date('Y-m-d H:i:s');
             $model->updated_at=date('Y-m-d H:i:s');


             if($model->validate() && $model->save(false)){
                Yii::$app->getSession()->setFlash('success', 'Successfully created new Business Type');

            return $this->redirect(['business-type/index']);
            }
            else
            {
                Yii::$app->getSession()->setFlash('error', "Can't create duplicate Business Type");
                return $this->redirect(['business-type/index']);
            }
        }

        return $this->render('/leads/business-type/index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'model' => $model,
        ]);
    }

    /**
     * Displays a single BusinessType model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        Yii::$app->view->params['active']=9;
        return $this->render('/leads/business-type/view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new BusinessType model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        Yii::$app->view->params['active']=9;
        $model = new BusinessType();

        if ($model->load(Yii::$app->request->post()) ) {

             $model->created_at=date('Y-m-d H:i:s');
             $model->updated_at=date('Y-m-d H:i:s');
             $model->save(false);
            return $this->redirect(['business-type/view', 'id' => $model->id]);
        }

        return $this->render('/leads/business-type/create', [
            'model' => $model,
        ]);
    }

    /**
     * Updates an existing BusinessType model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        Yii::$app->view->params['active']=9;
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post())) {
            $model->updated_at=date('Y-m-d H:i:s');

             if($model->validate() && $model->save(false)){
               Yii::$app->getSession()->setFlash('success', 'Successfully updated Business Type');
               return $this->redirect(['business-type/index']);
            }

        }

        return $this->render('/leads/business-type/update', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing BusinessType model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id=null)
    {
        if($id==null)
        {
            $ids=Yii::$app->request->post('data');
            foreach($ids as $id){
            $this->findModel($id)->delete();
            }
            Yii::$app->getSession()->setFlash('success', 'Successfully Deleted selected Business Types');
            return $this->redirect(['business-type/index']);
        }
        else
        {
            $this->findModel($id)->delete();
            Yii::$app->getSession()->setFlash('success', 'Successfully Deleted');
            return $this->redirect(['business-type/index']);
        }
    }
     public function actionExportPdf()
    {
        $dataProvider = new ActiveDataProvider([
            'query' => BusinessType::find()->orderBy(['id' => SORT_DESC]),
        ]);
        $dataProvider->pagination = false;
        $mpdf = new mPDF;
        $mpdf->showImageErrors = true;
        $mpdf->WriteHTML($this->renderPartial('/leads/business-type/export-pdf', [
            'dataProvider' => $dataProvider,

        ]));
        $mpdf->Output('businesss_type.pdf', 'I');
    }

    public function actionExcelExport($detail=null)
    {
        $dataProvider = new ActiveDataProvider([
            'query' => BusinessType::find()->orderBy(['id' => SORT_DESC]),
        ]);
        if($detail){
    $exporter = new Spreadsheet([
        'dataProvider' => $dataProvider,
        'columns' => [
            'business_type_name',
            'created_at:date',
        
        ],
    ]);
        }else{
            // print_r("xxxxx");
            // exit();
            $exporter = new Spreadsheet([
                'dataProvider' => $dataProvider,
                'columns' => [
            'business_type_name',
                ],
            ]);
        }
    return $exporter->send('businesss_types.xlsx');
    }
    /**
     * Finds the BusinessType model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return BusinessType the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = BusinessType::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
