<?php

namespace backend\modules\master\controllers;

use Yii;
use backend\modules\master\models\GenericTemplate;
use backend\modules\master\models\GenericTemplateSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;


/**
 * GenericTemplateController implements the CRUD actions for GenericTemplate model.
 */
class GenericTemplateController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }


    public static $country=["India"=>"India",
    "Others"=>"Others",
   ]
    ;

    /**
     * Lists all GenericTemplate models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new GenericTemplateSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single GenericTemplate model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new GenericTemplate model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new GenericTemplate();

        if ($model->load(Yii::$app->request->post()) && $model->validate()) {
            
            $names = UploadedFile::getInstances($model, 'company_seal');
            foreach ($names as $name) {
                $path = 'template_seals/' . $name->baseName . '.' . $name->extension;
                if ($name->saveAs($path)) {
                    $filename = $name->baseName . '.' . $name->extension;
                    $filepath = $path;
                    $model->company_seal = $filename;
                }
            }
            $qrcode = UploadedFile::getInstances($model, 'qr_code');
            foreach ($qrcode as $qrcode) {
                $path = 'qr_codes/' . $qrcode->baseName . '.' . $qrcode->extension;
                if ($qrcode->saveAs($path)) {
                    $qrfilename = $qrcode->baseName . '.' . $qrcode->extension;
                    $model->qr_code = $qrfilename;
                }
            }
            if ($model->template_for == 'Invoice' || $model->template_for == 'Receipt' || $model->template_for == 'Credit Note' || $model->template_for == 'Proforma Invoice' || $model->template_for == 'Quotes' || $model->template_for == 'Sales Order') {
                $model->template_type = 'Sales';
            } else if($model->template_for == 'Purchase Order' || $model->template_for == 'Expense' || $model->template_for == 'Debit Note' || $model->template_for == 'Payment') {
                $model->template_type = 'Purchase';
            }
            else{
                
            }
            $model->save(false);
            return $this->redirect(['index']);
        }

        return $this->render('create', [
            'model' => $model,
            'update' => 0,
            'country' => VendorController::$country,
        ]);
    }

    /**
     * Updates an existing GenericTemplate model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);
        $logo = $model->company_seal;
        $qr = $model->qr_code;
        if ($model->load(Yii::$app->request->post())) {
            $names = UploadedFile::getInstances($model, 'company_seal');
            if (!empty($names)) {
                foreach ($names as $name) {
                    $path = 'template_seals/' . $name->baseName . '.' . $name->extension;
                    if ($name->saveAs($path)) {

                        $filename = $name->baseName . '.' . $name->extension;
                        $filepath = $path;
                        $model->company_seal = $filename;
                    }
                }
            } else {
                $model->company_seal = $logo;
            }
            $qrcode = UploadedFile::getInstances($model, 'qr_code');
            if (!empty($qrcode)) {
                foreach ($qrcode as $qrcode) {
                    $path = 'qr_codes/' . $qrcode->baseName . '.' . $qrcode->extension;
                    if ($qrcode->saveAs($path)) {
                        $qrfilename = $qrcode->baseName . '.' . $qrcode->extension;
                        $model->qr_code = $qrfilename;
                    }
                }
            }else{
                $model->qr_code = $qr;
            }
            if ($model->template_for == 'Invoice' || $model->template_for == 'Receipt' || $model->template_for == 'Credit Note' || $model->template_for == 'Proforma Invoice' || $model->template_for == 'Quotes' || $model->template_for == 'Sales Order') {
                $model->template_type = 'Sales';
            } else if($model->template_for == 'Purchase Order' || $model->template_for == 'Expense' || $model->template_for == 'Debit Note' || $model->template_for == 'Payment') {
                $model->template_type = 'Purchase';
            }
            else{
                
            }
            $model->save(false);
            return $this->redirect(['index']);
        }

        return $this->render('update', [
            'model' => $model,
            'update' => 1,
            'country' => VendorController::$country,
        ]);
    }
    /**
     * Deletes an existing GenericTemplate model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the GenericTemplate model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return GenericTemplate the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = GenericTemplate::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
    public function actionTemplatename($name = null)
    {
        $find = GenericTemplate::find()->Where(['template_name' => $name])->count();
        if ($find > 0) {
            echo '1';
        } else {
            echo '0';
        }
    }
}
