<?php

namespace backend\modules\master\controllers;

use Yii;
use backend\modules\master\models\LeadsEnquiry;
use backend\modules\master\models\LeadsEnquirySearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\data\ActiveDataProvider;
use backend\modules\master\models\BusinessType;
use backend\modules\master\models\EnquiryModes;
use backend\modules\master\models\CallStatus;
use Mpdf\Mpdf;
use yii2tech\spreadsheet\Spreadsheet;
/**
 * LeadsEnquiryController implements the CRUD actions for LeadsEnquiry model.
 */
class LeadsEnquiryController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all LeadsEnquiry models.
     * @return mixed
     */
    public function actionIndex()
    {
        Yii::$app->view->params['active']=5;
        $searchModel = new LeadsEnquirySearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $model = new LeadsEnquiry();
        $query=LeadsEnquiry::find()->orderBy([
                'id' => SORT_DESC,
              ]);
        $business=BusinessType::find()->all();
        $inquiry=EnquiryModes::find()->all();
        $call=CallStatus::find()->all();
        
        if ($model->load(Yii::$app->request->get()) ) {
            $query->andFilterWhere(['between', 'date', $model->from_date,$model->to_date])
            ->andFilterWhere(['like', 'name', $model->name])
            ->andFilterWhere(['like', 'mode_of_enquiry', $model->mode_of_enquiry])
            ->andFilterWhere(['like', 'call_status', $model->call_status])
            ->andFilterWhere(['like', 'city', $model->city])
            ->andFilterWhere(['like', 'business_type', $model->business_type]);
            }
            $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);
        return $this->render('/leads/leads-enquiry/index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'model' => $model,
            'modes_inquiry'=>$inquiry,
            'call_status'=>$call,
            'business_type'=>$business,
        ]);
    }

    /**
     * Displays a single LeadsEnquiry model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        Yii::$app->view->params['active']=5;
        return $this->render('/leads/leads-enquiry/view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new LeadsEnquiry model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        Yii::$app->view->params['active']=5;
        $model = new LeadsEnquiry();
        $business=BusinessType::find()->all();
        $inquiry=EnquiryModes::find()->all();
        $call=CallStatus::find()->all();
        if ($model->load(Yii::$app->request->post())) {

            $model->converted_to ='Pending';
            $model->save(false);
            Yii::$app->getSession()->setFlash('success', 'Created Successfully');
            return $this->redirect(['index']);
        }

        return $this->render('/leads/leads-enquiry/_form', [
            'model' => $model,
            'modes_inquiry'=>$inquiry,
            'call_status'=>$call,
            'business_type'=>$business,
            'update'=>0,
        ]);
    }

    /**
     * Updates an existing LeadsEnquiry model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        Yii::$app->view->params['active']=5;
        $model = $this->findModel($id);
        $business=BusinessType::find()->all();
        $inquiry=EnquiryModes::find()->all();
        $call=CallStatus::find()->all();
        if ($model->load(Yii::$app->request->post()) && $model->save(false)) {
            Yii::$app->getSession()->setFlash('success', 'Updated Successfully');
            return $this->redirect(['index']);
        }

        return $this->render('/leads/leads-enquiry/_form', [
            'model' => $model,
            'modes_inquiry'=>$inquiry,
            'call_status'=>$call,
            'business_type'=>$business,
            'update'=>1,
        ]);
    }

    /**
     * Deletes an existing LeadsEnquiry model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id=null)
    {
        Yii::$app->view->params['active']=5;
        if($id!=null)
        {
            $this->findModel($id)->delete();
            Yii::$app->getSession()->setFlash('success', 'Deleted Successfully');
            return $this->redirect(['index']);
        }
        else
        {
            $ids=Yii::$app->request->post('data');
            if($ids){
            foreach($ids as $id){
            $this->findModel($id)->delete();
            }
            }
            Yii::$app->getSession()->setFlash('success', 'Deleted Successfully');
            return $this->redirect(['index']);
        }
        
    }
    public function actionExcelExport($detail=null)
    {
        Yii::$app->view->params['active']=5;
        $dataProvider = new ActiveDataProvider([
            'query' => LeadsEnquiry::find(),
        ]);
        if($detail){
    $exporter = new Spreadsheet([
        'dataProvider' => $dataProvider,
        'columns' => [
            'name', 
            'email',
            'mobile',
             'address', 
             [
                'label'=>'Business Type',
               'attribute' => 'business_type',
               'value' => function ($data) {
                $value=BusinessType::find()->where(['id'=>$data->business_type])->one();
                return $value?$value->business_type_name:'';
               }
            ],
            [
                'label'=>'Mode of Inquiry',
               'attribute' => 'mode_of_enquiry',
               'value' => function ($data) {
                $value=EnquiryModes::find()->where(['id'=>$data->mode_of_enquiry])->one();
                return $value?$value->mode_of_enquiry:'';
               }
            ],
            [
                'label'=>'Call Status',
               'attribute' => 'call_status',
               'value' => function ($data) {
                $value=CallStatus::find()->where(['id'=>$data->call_status])->one();
                return $value?$value->call_status_name:'';
               }
            ],
               
               'date',
           
             'city', 
               'messages',
            // 'status',
            'created_at:date',
            'updated_at:date',
        ],
    ]);
        }else{
            $exporter = new Spreadsheet([
                'dataProvider' => $dataProvider,
                'columns' => [
                    'name', 
                    'email',
                    'mobile',
                     'address', 
                     [
                        'label'=>'Business Type',
                       'attribute' => 'business_type',
                       'value' => function ($data) {
                        $value=BusinessType::find()->where(['id'=>$data->business_type])->one();
                        return $value?$value->business_type_name:'';
                       }
                    ],
                    [
                        'label'=>'Mode of Inquiry',
                       'attribute' => 'mode_of_enquiry',
                       'value' => function ($data) {
                        $value=EnquiryModes::find()->where(['id'=>$data->mode_of_enquiry])->one();
                        return $value?$value->mode_of_enquiry:'';
                       }
                    ],
                      
                       'date',
                       'address',
                    // 'status',
                    
                ],
            ]);
        }
    if($detail)
    return $exporter->send('leads_enquiry_details.xlsx');
    return $exporter->send('leads_enquiry.xlsx');
    }
    public function actionExportPdf()
    {
        Yii::$app->view->params['active']=5;
        $dataProvider = new ActiveDataProvider([
            'query' => LeadsEnquiry::find(),
        ]);
        $dataProvider->pagination = false;
        $mpdf = new mPDF;
        $mpdf->WriteHTML($this->renderPartial('/leads/leads-enquiry/exportpdf', [
            'dataProvider' => $dataProvider,

        ]));
        $mpdf->Output('Leads_enquiry.pdf', 'D');
    }
    public function actionOptionData()
    {
        if(!Yii::$app->request->post('data')['mode_of_inquiry']&&
        !Yii::$app->request->post('data')['call_status']&&
        !Yii::$app->request->post('data')['business'])
        return json_encode([
            'required'=>"required",
        ]);
        if(Yii::$app->request->post('data')['mode_of_inquiry']){
            $model=new EnquiryModes();
            $model->mode_of_enquiry=Yii::$app->request->post('data')['mode_of_inquiry'];
            if(!$model->save()){
                return json_encode([
                    'error'=>"add-mode-enquiry",
                ]);
            }
        }
        elseif(Yii::$app->request->post('data')['call_status']){
        $model=new CallStatus();
        $model->call_status_name=Yii::$app->request->post('data')['call_status'];
        if(!$model->save()){
            return json_encode([
                'error'=>"call-status",
            ]);
        }
        }
        elseif(Yii::$app->request->post('data')['business']){
            $model=new BusinessType();
            $model->business_type_name=Yii::$app->request->post('data')['business'];
            if(!$model->save()){
                return json_encode([
                    'error'=>"business-type",
                ]);
            }
        }
        $business=BusinessType::find()->asArray()->all();
        $inquiry=EnquiryModes::find()->asArray()->all();
        $call=CallStatus::find()->asArray()->all();
      return json_encode([
          'inquiry'=>$inquiry,
          'call'=>$call,
          'business'=>$business,
          'error'=>false
      ]);
    }
    /**
     * Finds the LeadsEnquiry model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return LeadsEnquiry the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        Yii::$app->view->params['active']=5;
        if (($model = LeadsEnquiry::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
