<?php

namespace backend\modules\master\controllers;

use Yii;
use yii\helpers\ArrayHelper;
use yii\helpers\Url;
use backend\modules\master\models\Product;
use backend\modules\master\models\Vendor;
use backend\modules\master\models\ProductDocument;
use backend\modules\master\models\ProductUnit;
use backend\modules\master\models\ProductSearch;
use backend\modules\master\models\HsnCode;
use backend\modules\users\models\ProductInventory;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use backend\modules\master\models\Category;
use yii\web\UploadedFile;
use yii\data\ActiveDataProvider;
use Mpdf\Mpdf;
use yii2tech\spreadsheet\Spreadsheet;

/**
 * ProductController implements the CRUD actions for Product model.
 */
class ProductController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all Product models.
     * @return mixed
     */
    public function actionIndex()
    {
        Yii::$app->view->params['active']=7;
        $searchModel = new ProductSearch();
        $model=new Product();
        $category=Category::find()->all();
        $vendor=Vendor::find()->all();
        $unit=ProductUnit::find()->all();
        $query=Product::find();
        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'sort' => ['defaultOrder' => ['id' => SORT_DESC]],
        ]);
        if ($model->load(Yii::$app->request->get()) ) {

        $query->andFilterWhere(['like', 'product_name', $model->product_name]);
        $query->andFilterWhere(['like', 'category', $model->categorysearch])
        ->andFilterWhere(['like', 'purpose', $model->purpose])
        ->andFilterWhere(['like', 'model_name', $model->model_name])
        ->andFilterWhere(['like', 'product_code_sku', $model->product_code_sku])
        ->andFilterWhere(['like', 'vendor', $model->vendor])
        ->andFilterWhere(['like', 'show_inventory', $model->show_inventory]);
        if($model->tax_wise==1)
        $query->andFilterWhere(['=', 'selling_inclusive_of_tax', $model->tax_wise]);
        if($model->tax_wise==2)
        $query->andFilterWhere(['=', 'buying_inclusive_tax', 1]);
        if($model->tax_wise==3)
        $query->andFilterWhere(['=', 'selling_inclusive_of_tax', 0]);
        if($model->tax_wise==4)
        $query->andFilterWhere(['=', 'buying_inclusive_tax', 0]);
        }
        return $this->render('index', [
            'model'=>$model,
            'category'=>$category,
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'vendor'=>$vendor,
            'unit'=>$unit,
        ]);
    }

    /**
     * Displays a single Product model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        Yii::$app->view->params['active']=7;
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }


    public function actionSearchHsnCode($string=null)
    {
        if($string!=null)
        $data =  HSNCode::find()->where(['like','description',$string])->limit(10)->asArray()->all();
        else
        $data =  HSNCode::find()->limit(10)->asArray()->all();
        
        return json_encode($data);
    }

     public function actionSearchCategory($string=null)
    {
        if($string!=null)
        $data =  Category::find()->where(['like','name',$string])->limit(10)->asArray()->all();
        else
        $data =  Category::find()->limit(10)->asArray()->all();
        
        return json_encode($data);
    }
    /**
     * Creates a new Product model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate($id=null)
    {
        Yii::$app->view->params['active']=7;
        $model = new Product();
        $hsnmodel = new HSNCode();
        $categorymodel = new Category();
        if($id){
        $data = $this->findModel($id)->attributes;
        $model->setAttributes($data);
        }
        $category=Category::find()->all();
        $vendor=Vendor::find()->all();
        $unit=ProductUnit::find()->all();

        if ($categorymodel->load(Yii::$app->request->post()) ) {

            $categorymodel->name = $categorymodel->categoryname;
            $categorymodel->save(false);

        }

        if ($model->load(Yii::$app->request->post()) ) {
            $data=Yii::$app->request->post();
            $model->image = UploadedFile::getInstance($model,'image');
            if($model->image){
            $nameimage=(new \DateTime())->format('u');
            $model->image->saveAs('setting/product_documents_images/' .$nameimage.'.'.$model->image->extension);
            $model->image=$nameimage. '.' . $model->image->extension;
            }
            if($model->selling_tax_rate){
            if(!is_string($model->selling_tax_rate) )
            $model->selling_tax_rate=implode(',',$model->selling_tax_rate);
            }
            if(!$model->tax_rate){
            if(!is_string($model->tax_rate) == false)
            $model->tax_rate=implode(',',$model->tax_rate);
            }
            $model->page=1;
            if($model->save(false)){
            for($i=1;$i<=$data['imagecount'];$i++){
            $document = new ProductDocument();
            $document->document_name = UploadedFile::getInstanceByName('file'.$i);
            if($document->document_name){
            $nameimage=(new \DateTime())->format('u');
            $document->document_name->saveAs('setting/product_documents_images/' .$nameimage.$model->id.$document->document_name->name.'.'.$document->document_name->extension);
            $document->document_name=$nameimage.$model->id.$document->document_name->name. '.' . $document->document_name->extension; 
            $document->product_id=$model->id;
            $document->save();
            }
            }
                $inventory = new ProductInventory();
                $inventory->product_id = $model->id;
                $inventory->status = 1;
                $inventory->date = date("Y-m-d H:i:s");
                if($model->opening_stock==0 || $model->opening_stock=='')
                {
                    if($model->bying_price!='')
                    {
                        $inventory->price = $model->bying_price;
                    }
                    else
                    {
                        $inventory->price = 0;
                    }
                    $inventory->quantity = 0;
                }
                else
                {
                    if($model->bying_price!='')
                    {
                        $inventory->price = $model->bying_price;
                    }
                    else
                    {
                        $inventory->price = '0';
                    }
                    $inventory->quantity = $model->opening_stock;
                }
                $inventory->save();
            // Yii::$app->getSession()->setFlash('success', 'Created Successfully');
            return $this->redirect(['update','id'=>$model->id,'page'=>2]);
        }
        }

        return $this->render('_form', [
            'update'=>0,
            'model' => $model,
            'category'=>$category,
            'vendor'=>$vendor,
            'unit'=>$unit,
            'hsnmodel'=>$hsnmodel,
            'categorymodel'=>$categorymodel,
        ]);
    }

    /**
     * Updates an existing Product model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id,$page)
    {
        if($page>7){
            return $this->redirect(['index']);
        }
        Yii::$app->view->params['active']=7;
        $model = $this->findModel($id);
         $hsnmodel = new HSNCode();
         $categorymodel = new Category();
        if($page>$model->page+1){
            return $this->redirect(Yii::$app->request->referrer);
        }
        $oldimage=$model->image;
        $category=Category::find()->all();
        $vendor=Vendor::find()->all();
        $unit=ProductUnit::find()->all();
        $doc=ProductDocument::find()->where(['product_id'=>$id])->all();
        if($hsnmodel->load(Yii::$app->request->post()))
        {
                $hsnmodel->code = $hsnmodel->hsncode;
                $hsnmodel->description = $hsnmodel->code_desc;
                $hsnmodel->save(false);
                $hsnmodel = new HSNCode();

        }
        if ($categorymodel->load(Yii::$app->request->post()) ) {

            $categorymodel->name = $categorymodel->categoryname;
            $categorymodel->save(false);
            $categorymodel = new Category();

        }
        if ($model->load(Yii::$app->request->post())) {
            $data=Yii::$app->request->post();
            $newids=[];
            if($page==1){
            for($i=1;$i<=$data['imagecount'];$i++){ 
                $newids[]=Yii::$app->request->post('file'.$i);
            }
            $oldids=ArrayHelper::map($doc, 'id', 'id');
            $diffids=array_diff($oldids,$newids);
        }
            $model->image = UploadedFile::getInstance($model,'image');
            if($model->image){
            $nameimage=(new \DateTime())->format('u');
            $model->image->saveAs('setting/product_documents_images/' .$nameimage.'.'.$model->image->extension);
            $model->image=$nameimage. '.' . $model->image->extension;
            }else{
                $model->image=$oldimage;
            }
            if($model->selling_tax_rate){
                if(!is_string($model->selling_tax_rate))
                $model->selling_tax_rate=implode(',',$model->selling_tax_rate);
                }
            if($model->tax_rate){
                if(!is_string($model->tax_rate))
                $model->tax_rate=implode(',',$model->tax_rate);
                }

            if($model->bying_price=='')
            {
                $model->bying_price='0';
            }
            if($model->selling_price=='')
            {
                $model->selling_price='0';
            } 
            


            // $model->page=$page;

            //  if($page==7){
            //        if($model->stock_unit=='')
            //        {
            //            $model->stock_unit = 0;
            //            $model->on_create_stock=0;
            //        }
            //        else
            //        {
            //           if($model->on_create_stock ===NULL)
            //           {
                        

               $model->on_create_stock=$model->stock_unit;
               //        }
               //     }
               // }
               $model->page=$page;
            if($model->save(false)){
            if($page==1){
            ProductDocument::deleteAll(['in','id',$diffids]);
            for($i=2;$i<=$data['imagecount']+1;$i++){ 
            if(!Yii::$app->request->post('file'.$i)){
            $document = new ProductDocument();
            $document->document_name = UploadedFile::getInstanceByName('file'.$i);
            if($document->document_name){
            $nameimage=(new \DateTime())->format('u');
            $document->document_name->saveAs('setting/product_documents_images/' .$nameimage.$model->id.$document->document_name->name.'.'.$document->document_name->extension);
            $document->document_name=$nameimage.$model->id.$document->document_name->name. '.' . $document->document_name->extension; 
            $document->product_id=$model->id;
            $document->save();
            }
            }
            }
        }

            $inventory = ProductInventory::find()->where(['product_id'=>$model->id])->andWhere(['status'=>1])->one();
                $inventory->product_id = $model->id;
                $inventory->status = 1;
                $inventory->date = date("Y-m-d H:i:s");
                if($model->opening_stock==0 || $model->opening_stock=='')
                {
                    if($model->bying_price!='')
                    {
                        $inventory->price = $model->bying_price;
                    }
                    else
                    {
                        $inventory->price = 0;
                    }
                    $inventory->quantity = 0;
                }
                else
                {
                    if($model->bying_price!='')
                    {
                        $inventory->price = $model->bying_price;
                    }
                    else
                    {
                        $inventory->price = '0';
                    }
                    $inventory->quantity = $model->opening_stock;
                }
                $inventory->save();

            if($model->page==7){
            if(!$model->is_finalize){
                $model->is_finalize=1;
                $model->save(false);
            }
            Yii::$app->getSession()->setFlash('success', 'Saved Successfully');
            return $this->redirect(['index']);
            }else{
                return $this->redirect(['update','id'=>$id,'page'=>$page+1]);

            }
        }
        }

        return $this->render('_form', [
            'update'=>1,
            'model' => $model,
            'category'=>$category,
            'vendor'=>$vendor,
            'unit'=>$unit,
            'doc'=>$doc,
            'hsnmodel'=>$hsnmodel,
            'categorymodel'=>$categorymodel,
        ]);
    }

    /**
     * Deletes an existing Product model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDuplicate($id)
    {
        Yii::$app->view->params['active']=7;
        // $model=new Product();
        // $data = $this->findModel($id)->attributes;
        // $model->setAttributes($data);
        // $model->save();
        // $document=ProductDocument::find()->where(['product_id'=>$id])->all();
        // foreach($document as $value){
        //     $data = $value->attributes;
        //     $model->setAttributes($data);
        //     $model->save();  
        // }
        // Yii::$app->getSession()->setFlash('success', 'Created Successfully');
        return $this->redirect(['create','id'=>$id]);
    }
    public function actionDelete($id=null)
    {
        Yii::$app->view->params['active']=7;
        if($id=='')
        {
            $ids=Yii::$app->request->post('data');
            if($ids){
            foreach($ids as $id){
            $document=ProductDocument::find()->where(['product_id'=>$id])->all();
            foreach($document as $value){$value->delete();}
            $this->findModel($id)->delete();
            }
            }
            Yii::$app->getSession()->setFlash('success', 'Deleted Successfully');
            return $this->redirect(['index']);
        }
        else
        {
            $this->findModel($id)->delete();
            $document=ProductDocument::find()->where(['product_id'=>$id])->all();
            foreach($document as $value){$value->delete();}
            Yii::$app->getSession()->setFlash('success', 'Deleted Successfully');
            return $this->redirect(['index']);
        }     
    }
    Public function actionDownloadAttachment($id)
    {
    Yii::$app->view->params['active']=7;
    $data=ProductDocument::find()->where(['product_id'=>$id])->all();
    if(!$data){
    Yii::$app->getSession()->setFlash('success', 'No Attachment Found');
    return $this->redirect(['index']);
    }
    $file = Yii::$app->basePath.'/web/setting/product_documents_images/product_'.$id.'.zip';
    $zip = new \ZipArchive();
    $zip->open($file, \ZipArchive::CREATE | \ZipArchive::OVERWRITE) ;
    foreach($data as $value){
       $files[]=Yii::$app->basePath . '/web/setting/product_documents_images/'.$value->document_name;
    }
    foreach($files as $val){
        $zip->addFromString(basename($val), file_get_contents($val));
    }
    $zip->close();
    return Yii::$app->response->sendFile($file);
    }
    public function actionFindattachments($id)
    {
       $documents= ProductDocument::find()->where(['product_id'=>$id])->asArray()->all();
       echo json_encode($documents);
    }
    public function actionDownload($id) 
    {
        $model=ProductDocument::find()->where(['id'=>$id])->one();
        if($model->document_name!=null)
        {
            $name=Yii::$app->basePath . '/web/setting/product_documents_images/'.$model->document_name;
            if(file_exists($name))
            {
               return yii::$app->response->sendFile($name);
            }
            else{
                Yii::$app->getSession()->setFlash('success', 'No Attachment Found');
                return $this->redirect(['index']); 
            }
        }else{
            Yii::$app->getSession()->setFlash('success', 'No Attachment Found');
            return $this->redirect(['index']);
        }
    }
    public function actionExcelExport($detail=null)
    {
        Yii::$app->view->params['active']=7;
        $dataProvider = new ActiveDataProvider([
            'query' => Product::find(),
        ]);
        if($detail){
    $exporter = new Spreadsheet([
        'dataProvider' => $dataProvider,
        'columns' => [
            'product_name',
            // [
            //     'label' => 'Category',
            //     'value' => function ($data) {
            //         $catagory = Category::find()->where(['id'=>$model->category])->one();;
            //     }
            // ],
            'category',
            'alias_name',
            'model_name',
            'model_no',
            'image',
            'description:ntext',
            'purpose',
            'vendor',
            'different_income_category',
            'income_account',
            'selling_price',
            'counter_price',
            'distributor_price',
            'govt_without_rc_price',
            'industry_price',
            'marine_product_price',
            'rate_contract_price',
            'private_lab_price',
            'school_college_price',
            'mrp',
            'multiple_prices',
            'selling_tax_rate:ntext',
            'selling_inclusive_of_tax',
            'mrp_margin',
            'mrp_margin_type',
            'diff_expense_category',
            'expense_account',
            'bying_price',
            'buying_inclusive_tax',
            'tax_rate',
            'diff_currency',
            'currency',
            'default_currency_price',
            'opening_stock',
            'opening_rate_per_unit',
            'product_code_sku',
            'barcode',
            'product_type',
            'hsn_sac_code',
            'show_inventory',
            'show_screen_pos',
            'show_after_subtotal',
            'min_order_level',
            're_order_level',
            'max_order_level',
            'units',
            'stock_unit',
            'conversion_ratio',
            'created_at:date',
            'updated_at:date'
        ],
    ]);
        }else{
            $exporter = new Spreadsheet([
                'dataProvider' => $dataProvider,
                'columns' => [
                'product_name',
            'product_code_sku',
            'barcode',
            'description',
            'conversion_ratio',
            // 'created_at',
            'bying_price',
            'created_at:date',
                ],
            ]);
        }
    if($detail)
    return $exporter->send('product_details.xlsx');
    return $exporter->send('product.xlsx');

    }
    public function actionExportPdf()
    {
        Yii::$app->view->params['active']=7;
        $dataProvider = new ActiveDataProvider([
            'query' => Product::find(),
        ]);
        $dataProvider->pagination = false;
        $mpdf = new mPDF;
        $mpdf->WriteHTML($this->renderPartial('exportpdf', [
            'dataProvider' => $dataProvider,

        ]));
        $mpdf->Output('product.pdf', 'I');
    }
    public function actionUniqueValidation($name,$category,$update=null,$id=null,$page=null)
    {  
    if($update){
    if($page==1){
    $count1=Product::find()->where(['product_name'=>$name,'category'=>$category,'id'=>$id])->count();
    $count2=Product::find()->where(['product_name'=>$name,'category'=>$category])->count();
    
    }
        else{
        $categoryind=Product::find()->where(['id'=>$id])->one();
        $count1=Product::find()->where(['product_name'=>$name,'category'=>$categoryind->category,'id'=>$id])->count();
        $count2=Product::find()->where(['product_name'=>$name,'category'=>$categoryind->category])->count();
        
    }
    if($count1 && $count2<=1 )
    return 1;
    if(!$count1)
    return 1;
    }

    }
    public function actionUniqueValidationCreate($name,$category)
    { 
        
      $count=Product::find()->where(['product_name'=>$name,'category'=>$category])->count();
      if($count>=1)
      return 0;
      return 1;
    }
    /**
     * Finds the Product model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Product the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        Yii::$app->view->params['active']=7;
        if (($model = Product::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
