<?php

namespace backend\modules\master\controllers;

use Yii;
use backend\modules\master\models\ProductPricelist;
use backend\modules\master\models\ProductPricelistSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;
use yii\data\ActiveDataProvider;
use Mpdf\Mpdf;
use yii2tech\spreadsheet\Spreadsheet;
/**
 * ProductPricelistController implements the CRUD actions for ProductPricelist model.
 */
class ProductPricelistController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all ProductPricelist models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new ProductPricelistSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('/product/product-pricelist/index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single ProductPricelist model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('/product/product-pricelist/view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new ProductPricelist model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new ProductPricelist();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id]);
        }

        return $this->render('/product/product-pricelist/create', [
            'model' => $model,
        ]);
    }

    /**
     * Updates an existing ProductPricelist model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id]);
        }

        return $this->render('/product/product-pricelist/update', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing ProductPricelist model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }
    public function actionDeletePricelist()
    {
        $ids=Yii::$app->request->post('data');
        if($ids){
        foreach($ids as $id){
        $this->findModel($id)->delete();
        }
    }
        return $this->redirect(['index']);
    }
    public function actionExcelExport($detail=null)
    {
        $dataProvider = new ActiveDataProvider([
            'query' => ProductPricelist::find(),
        ]);
        if($detail){
    $exporter = new Spreadsheet([
        'dataProvider' => $dataProvider,
        'columns' => [
            'name',
            ['label' => 'Status',
            'attribute' => 'status',
            'value' => function($data){
            return $data->status?"Active":"Inactive";
             }
         ],
            'created_at:date',
        ],
    ]);
        }else{
            $exporter = new Spreadsheet([
                'dataProvider' => $dataProvider,
                'columns' => [
                    'name',
                    ['label' => 'Status',
                    'attribute' => 'status',
                    'value' => function($data){
                    return $data->status?"Active":"Inactive";
                     }
                 ],
                ],
            ]);
        }
    return $exporter->send('product_pricelist.xlsx');
    }
    public function actionExportPdf()
    {
        $dataProvider = new ActiveDataProvider([
            'query' => ProductPricelist::find(),
        ]);
        $dataProvider->pagination = false;
        $mpdf = new mPDF;
        $mpdf->WriteHTML($this->renderPartial('/product/product-pricelist/exportpdf', [
            'dataProvider' => $dataProvider,

        ]));
        $mpdf->Output('product_pricelist.pdf', 'D');
    }
    /**
     * Finds the ProductPricelist model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return ProductPricelist the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = ProductPricelist::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
