<?php

namespace backend\modules\master\controllers;

use Yii;
use backend\modules\master\models\ProductUnit;
use backend\modules\master\models\ProductUnitSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\data\ActiveDataProvider;
use Mpdf\Mpdf;
use yii2tech\spreadsheet\Spreadsheet;
/**
 * ProductUnitController implements the CRUD actions for ProductUnit model.
 */
class ProductUnitController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all ProductUnit models.
     * @return mixed
     */
    public function actionIndex()
    {
        Yii::$app->view->params['active']=4;
        $searchModel = new ProductUnitSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('/product/product-unit/index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single ProductUnit model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        Yii::$app->view->params['active']=4;
        return $this->render('/product/product-unit/view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new ProductUnit model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        Yii::$app->view->params['active']=4;
        $model = new ProductUnit();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            Yii::$app->getSession()->setFlash('success', 'Created Successfully');
            return $this->redirect(['index']);
        }

        return $this->render('/product/product-unit/create', [
            'model' => $model,
        ]);
    }

    /**
     * Updates an existing ProductUnit model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        Yii::$app->view->params['active']=4;
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            Yii::$app->getSession()->setFlash('success', 'Updated Successfully');

            return $this->redirect(['index']);
        }

        return $this->render('/product/product-unit/update', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing ProductUnit model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id=null)
    {
        Yii::$app->view->params['active']=4;
        if($id==null)
        {
            $ids=Yii::$app->request->post('data');
            if($ids){
            foreach($ids as $id){
            $this->findModel($id)->delete();
            }
            }
            Yii::$app->getSession()->setFlash('success', 'Deleted Successfully');
            return $this->redirect(['index']);
        }
        else
        {
            $this->findModel($id)->delete();
            Yii::$app->getSession()->setFlash('success', 'Deleted Successfully');
            return $this->redirect(['index']);
        }  
    }
    public function actionExcelExport($detail=null)
    {
        Yii::$app->view->params['active']=4;
        $dataProvider = new ActiveDataProvider([
            'query' => ProductUnit::find(),
        ]);
        if($detail){
    $exporter = new Spreadsheet([
        'dataProvider' => $dataProvider,
        'columns' => [
            'unit_name',
            ['label' => 'Is Piece Unit',
            'attribute' => 'is_piece_unit',
            'value' => function($data){
            return $data->is_piece_unit?"Yes":"No";
             }
         ],
            'created_at:date',
            'updated_at:date',
        ],
    ]);
        }else{
            $exporter = new Spreadsheet([
                'dataProvider' => $dataProvider,
                'columns' => [
                    'unit_name',
                ],
            ]);
        }
    if($detail)
    return $exporter->send('product_unit_details.xlsx');
    return $exporter->send('product_unit.xlsx');
    }
    public function actionExportPdf()
    {
        Yii::$app->view->params['active']=4;
        $dataProvider = new ActiveDataProvider([
            'query' => ProductUnit::find(),
        ]);
        $dataProvider->pagination = false;
        $mpdf = new mPDF;
        $mpdf->WriteHTML($this->renderPartial('/product/product-unit/exportpdf', [
            'dataProvider' => $dataProvider,

        ]));
        $mpdf->Output('product_unit.pdf', 'I');
    }
    /**
     * Finds the ProductUnit model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return ProductUnit the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        Yii::$app->view->params['active']=4;
        if (($model = ProductUnit::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
