<?php

namespace backend\modules\master\controllers;

use Yii;
use backend\modules\master\models\SalesTemplates;
use backend\modules\master\models\SalesTemplatesSearch;
use backend\modules\users\models\CreditNote;
use backend\modules\users\models\Invoice;
use backend\modules\users\models\ProformaInvoice;
use backend\modules\users\models\ReceiptDetails;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * SalesTemplatesController implements the CRUD actions for SalesTemplates model.
 */
class SalesTemplatesController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all SalesTemplates models.
     * @return mixed
     */
    public function actionIndex()
    {
       
        $searchModel = new SalesTemplatesSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $dataProvider->sort->defaultOrder=['id'=>SORT_DESC];

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single SalesTemplates model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new SalesTemplates model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new SalesTemplates();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['index']);
        }

        return $this->render('create', [
            'model' => $model,
            'update'=>0,
        ]);
    }

    /**
     * Updates an existing SalesTemplates model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);
        $oldname = $model->template_name;
        $oldsetting = $model->setting_type;
        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            if($oldsetting =='Invoice')
            {
            $allinv = Invoice::find()->where(['settings_id'=>$oldname])->all();
                foreach($allinv as $val)
                {
                $val->settings_id = $model->template_name;
                $val->save(false);
                }

            }
            elseif($oldsetting =='Proforma Invoice')
            {
                $allpur = ProformaInvoice::find()->where(['setting_id'=>$oldname])->all();
                foreach($allpur as $val)
                {
                $val->setting_id = $model->template_name;
                $val->save(false);
                }
            }
            elseif($oldsetting =='Credit Note')
            {
                $allcredit = CreditNote::find()->where(['setting_type'=>$oldname])->all();
                foreach($allcredit as $val)
                {
                $val->setting_type = $model->template_name;
                $val->save(false);
                }
            }
            elseif($oldsetting =='Receipt')
            {
                $allpurchase = ReceiptDetails::find()->where(['setting_type'=>$oldname])->all();
                foreach($allpurchase as $val)
                {
                $val->setting_type = $model->template_name;
                $val->save(false);
                }
            }
            else
            {
                $allpurchase = SalesTemplates::find()->where(['setting_type'=>$oldname])->all();
                foreach($allpurchase as $val)
                {
                $val->setting_type = $model->template_name;
                $val->save(false);
                }
            }
            return $this->redirect(['index']);
        }

        return $this->render('update', [
            'model' => $model,
            'update'=> 1,
        ]);
    }

    /**
     * Deletes an existing SalesTemplates model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id=null)
    {
        if($id==null)
        {
            $ids=Yii::$app->request->post('data');
            if($ids)
            {
                foreach ($ids as $id) { 
                   $data=$this->findModel($id)->delete();
                }
            }
            Yii::$app->getSession()->setFlash('success', 'Successfully deleted selected items');
            return $this->redirect(['sales-templates/index']);
        }
        else
        {
            $data=$this->findModel($id)->delete();
             Yii::$app->getSession()->setFlash('success', 'Successfully deleted'); 
            return $this->redirect(['sales-templates/index']);
        }
    }
    public function actionFindsetting($setting=null,$template=null)
    {
        $find = SalesTemplates::find()->where(['setting_type'=>$setting])->andWhere(['template_name'=>$template])->count();
        if($find>0)
        {
            echo '0';
        }
        else
        {
            echo '1';
        }
    }

    public function actionFindusedtemplates()
    {
        $setting=Yii::$app->request->post('setting');
        $from=Yii::$app->request->post('from');
        if($from=='delete')
        {
            $count = 0;
            foreach ($setting as $val) {
                $findsetting = SalesTemplates::find()->where(['id'=>$val])->one();
                if($findsetting->setting_type=='Invoice')
                   {
                      $find = Invoice::find()->where(['settings_id'=>$findsetting->template_name])->andWhere(['is_deleted'=>0])->count();
                      if($find>0)
                    {
                        $count = $count+1;
                    }
                    else
                    {
                        $count = $count;
                    }
                   }
                   else if($findsetting->setting_type=='Proforma Invoice')
                   {
                    $find = ProformaInvoice::find()->where(['settings_id'=>$findsetting->template_name])->andWhere(['is_deleted'=>0])->count();
                    if($find>0)
                    {
                        $count = $count+1;
                    }
                    else
                    {
                        $count = $count;
                    }
                   }
                   else if($findsetting->setting_type=='Credit Note')
                   {
                    $find = CreditNote::find()->where(['setting_type'=>$findsetting->template_name])->andWhere(['is_deleted'=>0])->count();
                    if($find>0)
                    {
                        $count = $count+1;
                    }
                    else
                    {
                        $count = $count;
                    }
                   }
                   else if($findsetting->setting_type=='Receipt')
                   {
                    $find = ReceiptDetails::find()->where(['setting_type'=>$findsetting->template_name])->andWhere(['is_deleted'=>0])->count();  
                    if($find>0)
                    {
                        $count = $count+1;
                    }
                    else
                    {
                        $count = $count;
                    }
                   }
                   else
                   {
                        $count = $count;
                   }
            }
            if($count>0)
            {
                echo 0;
            }
            else
            {
                echo 1;
            }
        }
        else
        {
            $findsetting = SalesTemplates::find()->where(['id'=>$setting])->one();
           if($findsetting->setting_type=='Invoice')
           {
              $find = Invoice::find()->where(['settings_id'=>$findsetting->template_name])->andWhere(['is_deleted'=>0])->count();
              if($find>0)
            {
                echo '0'; 
            }
            else
            {
                echo '1';
            }
           }
           else if($findsetting->setting_type=='Proforma Invoice')
           {
            $find = ProformaInvoice::find()->where(['settings_id'=>$findsetting->template_name])->andWhere(['is_deleted'=>0])->count();
            if($find>0)
            {
                echo '0'; 
            }
            else
            {
                echo '1';
            }
           }
           else if($findsetting->setting_type=='Credit Note')
           {
            $find = CreditNote::find()->where(['setting_type'=>$findsetting->template_name])->andWhere(['is_deleted'=>0])->count();
            if($find>0)
            {
                echo '0'; 
            }
            else
            {
                echo '1';
            }
           }
           else if($findsetting->setting_type=='Receipt')
           {
            $find = ReceiptDetails::find()->where(['setting_type'=>$findsetting->template_name])->andWhere(['is_deleted'=>0])->count();  
            if($find>0)
            {
                echo '0'; 
            }
            else
            {
                echo '1';
            }
           }
           else
           {

           }
        }
       
     
        
    }
     public function actionCheckdeleteitems()
     {
            $ids=Yii::$app->request->post('data');
            $count = 0;
            $check = 0;
            $setting = '';
             foreach ($ids as $key => $value) {
                $findsetting = SalesTemplates::find()->where(['id'=>$value])->one();
                if($count==0)
                {
                    
                    $setting= $findsetting->setting_type;
                }
                if($setting!=$findsetting->setting_type)
                {
                    $check = $check + 1;
                }
                $count++;
             }
             if($check>0)
             {
                 echo 0;
             }
             else
             {
                echo 1;
             }
     }

    /**
     * Finds the SalesTemplates model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return SalesTemplates the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = SalesTemplates::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
