<?php

namespace backend\modules\master\controllers;

use Yii;
use backend\modules\master\models\TaxClass;
use backend\modules\master\models\TaxClassSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use Mpdf\Mpdf;
use yii\data\ActiveDataProvider;
use yii2tech\spreadsheet\Spreadsheet;

/**
 * TaxClassController implements the CRUD actions for TaxClass model.
 */
class TaxClassController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    // 'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all TaxClass models.
     * @return mixed
     */
    public function actionIndex()
    {
        Yii::$app->view->params['active']=10;
        $searchModel = new TaxClassSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('/tax/tax-class/index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single TaxClass model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        Yii::$app->view->params['active']=10;
        return $this->render('/tax/tax-class/view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new TaxClass model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        Yii::$app->view->params['active']=10;
        $model = new TaxClass();

        if ($model->load(Yii::$app->request->post())) {
             $model->created_at=date('Y-m-d H:i:s');
             $model->updated_at=date('Y-m-d H:i:s');
             if($model->validate() && $model->save(false)){
                Yii::$app->getSession()->setFlash('success', 'Successfully created new Tax class');
                return $this->redirect(['tax-class/index']);
            }

        }

        return $this->render('/tax/tax-class/create', [
            'model' => $model,
        ]);
    }

    /**
     * Updates an existing TaxClass model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        Yii::$app->view->params['active']=10;
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post())) {
             $model->updated_at=date('Y-m-d H:i:s');

             if($model->validate() && $model->save(false))
             {
             Yii::$app->getSession()->setFlash('success', 'Successfully updated');
             return $this->redirect(['tax-class/index']);
        }

        }

        return $this->render('/tax/tax-class/update', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing TaxClass model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id=null)
    {
        if($id=='')
        {
            $ids=Yii::$app->request->post('data');
            foreach($ids as $id){
            $this->findModel($id)->delete();
            }
            Yii::$app->getSession()->setFlash('success', 'Successfully deleted selected tax classes');
            return $this->redirect(['tax-class/index']);
        }
        else
        {
            $this->findModel($id)->delete();
            Yii::$app->getSession()->setFlash('success', 'Successfully deleted');
            return $this->redirect(['tax-class/index']);
        }
        
    }
    public function actionExportPdf()
    {
        $dataProvider = new ActiveDataProvider([
            'query' => TaxClass::find()->orderBy(['id' => SORT_DESC]),
        ]);
        $dataProvider->pagination = false;
        $mpdf = new mPDF;
        $mpdf->showImageErrors = true;
        $mpdf->WriteHTML($this->renderPartial('/tax/tax-class/export-pdf', [
            'dataProvider' => $dataProvider,

        ]));
        $mpdf->Output('tax_classes.pdf', 'I');
    }

    public function actionExcelExport($detail=null)
    {
        $dataProvider = new ActiveDataProvider([
            'query' => TaxClass::find()->orderBy(['id' => SORT_DESC]),
        ]);
        if($detail){
            $exporter = new Spreadsheet([
                'dataProvider' => $dataProvider,
                'columns' => [
                    'tax_class_name',
                    'tax_class_code',
                    'remarks',
                ],
            ]);
        }else{
            // print_r("xxxxx");
            // exit();
            $exporter = new Spreadsheet([
                'dataProvider' => $dataProvider,
                'columns' => [
                  'tax_class_name',
                  'tax_class_code',
                ],
            ]);
        }
    return $exporter->send('tax_classes.xlsx');
    }

    /**
     * Finds the TaxClass model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return TaxClass the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = TaxClass::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
