<?php

namespace backend\modules\master\models;

use Yii;

/**
 * This is the model class for table "accounting_ledger".
 *
 * @property int $accounting_ledger_id
 * @property string $taxable_ledger
 * @property string $ledger_id
 * @property int $group_name_id
 * @property string $name
 * @property string $alias_name
 * @property float $opening_balance
 * @property int $msic_code
 * @property string $created_at
 * @property string $updated_at
 *
 * @property GroupName $groupName
 */
class AccountingLedger extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    // const SCENARIO_OTHERS = 'others';

    // public function scenarios()
    // {
    //     $scenarios[self::SCENARIO_OTHERS] = ['name'];
    //     return $scenarios;

    // }
    public static function tableName()
    {
        return 'accounting_ledger';
    }
    public $full_url;

    /**
     * {@inheritdoc}
     */
    public function rules()
    {  
        return [
            [['name'], 'unique'],
            [['name'], 'required'],
            [['group_name_id','account_type_id'],'integer'],
            [['opening_balance'], 'number','numberPattern'=>'/^\d+(.\d{1,2})?$/', 'message'=> 'Integer or decimal value upto 2 digit is required'],
            [['msic_code'], 'match','pattern'=>'/^[0-9]{5}$/', 'message'=> 'must contain exactly 5 digits.'],
            [['created_at', 'updated_at'], 'safe'],
            [['taxable_ledger', 'alias_name'], 'string', 'max' => 50],
            [['ledger_id', 'name'], 'string', 'max' => 100],
            [['group_name_id'], 'exist', 'skipOnError' => true, 'targetClass' => GroupName::className(), 'targetAttribute' => ['group_name_id' => 'group_name_id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
//     public function is5NumbersOnly($attribute)
// {
//     if (!preg_match('/^[0-9]{5}$/', $this->$attribute)) {
//         $this->addError($attribute, 'must contain exactly 5 digits.');
//     }
// }

    public function attributeLabels()
    {
        return [
            'accounting_ledger_id' => 'Accounting Ledger ID',
            'taxable_ledger' => 'Taxable Ledger',
            'ledger_id' => 'Account Name',
            'account_type_id' => 'Account Type ',
            'group_name_id' => 'Group Name ',
            'name' => ' Ledger Name',
            'alias_name' => 'Alias Name',
            'opening_balance' => 'Opening Balance',
            'msic_code' => 'Msic Code',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
        ];
    }

    /**
     * Gets query for [[GroupName]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getGroupName()
    {
        return $this->hasOne(GroupName::className(), ['group_name_id' => 'group_name_id']);
    }
}
