<?php

namespace backend\modules\master\models;

use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\master\models\AccountingTax;

/**
 * AccountingTaxSearch represents the model behind the search form of `backend\modules\master\models\AccountingTax`.
 */
class AccountingTaxSearch extends AccountingTax
{
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['accounting_tax_id','is_deleted','status'], 'integer'],
            [['tax_name','tax_type', 'tax_class', 'abbreviation', 'tax_sub_type', 'supply_type', 'ledger_name', 'status', 'created_at', 'updated_at','tax_rate'], 'safe'],
            [['tax_rate'], 'number'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = AccountingTax::find()->where(['is_deleted'=>0]);

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'sort'=> ['defaultOrder' => ['accounting_tax_id' => SORT_DESC]],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'accounting_tax_id' => $this->accounting_tax_id,
            'tax_type' => $this->tax_type,
            'tax_rate' => $this->tax_rate,
            'is_deleted' => $this->is_deleted,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ]);

        $query->andFilterWhere(['like', 'tax_name', $this->tax_name])
            ->andFilterWhere(['like', 'tax_class', $this->tax_class])
            ->andFilterWhere(['like', 'abbreviation', $this->abbreviation])
            ->andFilterWhere(['like', 'tax_sub_type', $this->tax_sub_type])
            ->andFilterWhere(['like', 'supply_type', $this->supply_type])
            ->andFilterWhere(['like', 'ledger_name', $this->ledger_name])
            ->andFilterWhere(['like', 'tax_type', $this->tax_type])
            ->andFilterWhere(['like', 'status', $this->status])
            ->andFilterWhere(['like', 'tax_rate', $this->tax_rate]);


        return $dataProvider;
    }
}
