<?php

namespace backend\modules\master\models;

use Yii;

/**
 * This is the model class for table "generic_template".
 *
 * @property int $gt_id
 * @property string|null $template_name
 * @property string|null $template_for
 * @property string|null $company_name
 * @property string|null $address
 * @property string|null $city
 * @property string|null $state
 * @property string|null $pin
 * @property string|null $country
 * @property string|null $mobile
 * @property string|null $phone_no
 * @property string|null $gst_no
 * @property string|null $fax_no
 * @property string|null $trade_licence
 * @property string|null $email
 * @property string|null $terms_and_condition
 * @property string|null $bank_name
 * @property string|null $account_holder
 * @property string|null $acc_no
 * @property string|null $ifsc_code
 * @property string|null $company_seal
 * @property string|null $company_signature
 */
class GenericTemplate extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'generic_template';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['template_name', 'template_for', 'company_name', 'address', 'city', 'state', 'pin', 'country', 'mobile', 'phone_no', 'gst_no', 'fax_no', 'trade_licence', 'email', 'bank_name', 'account_holder', 'acc_no', 'ifsc_code'], 'string', 'max' => 256],

            [['template_name'], 'unique'],
            [['template_name','template_for'], 'required'],
            
            ['email','email'],
            ['email', 'unique','message'=>'This email has already exit'],

            [['mobile'],'string','min'=>10,'max'=>10],
            [['mobile','phone_no'], 'match', 'pattern' => '/^[0-9]+$/u'],

            [['pin'],'string'],
            [['pin'], 'match', 'pattern' => '/^[0-9]+$/u'],

            [['gst_no'], 'string','min'=>15, 'max' => 15],
            [['gst_no'], 'match' ,'pattern'=>'/^([0-9]){2}([A-Z]){4}([0-9A-Z]){1}([0-9]){4}([A-Z]){1}([0-9A-Z]){1}([0-9A-Z]){1}([0-9A-Z]){1}?$/', 'message'=> 'GSTN Format should be like  12ABCDE1234Z1Z1.'],

            [['terms_and_condition'], 'string', 'max' => 600],
            [['company_seal','qr_code'], 'string', 'max' => 100],
            [['company_signature'], 'string', 'max' => 50],
            [['company_seal','qr_code'], 'file','maxSize'=>2097152, 'message'=>'File has to be smaller than 2MB'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'gt_id' => 'Gt ID',
            'template_name' => 'Template Name',
            'template_for' => 'Template For',
            'company_name' => 'Company Name',
            'address' => 'Address',
            'city' => 'City',
            'state' => 'State',
            'pin' => 'Pin',
            'country' => 'Country',
            'mobile' => 'Mobile',
            'phone_no' => 'Phone No',
            'gst_no' => 'Gst No',
            'fax_no' => 'Fax No',
            'trade_licence' => 'Trade Licence',
            'email' => 'Email',
            'terms_and_condition' => 'Terms And Condition',
            'bank_name' => 'Bank Name',
            'account_holder' => 'Account Holder',
            'acc_no' => 'Acc No',
            'ifsc_code' => 'Ifsc Code',
            'company_seal' => 'Company Seal',
            'company_signature' => 'Company Signature',
            'qr_code' => 'QR Code',
        ];
    }
}
