<?php

namespace backend\modules\master\models;

use Yii;

/**
 * This is the model class for table "product".
 *
 * @property int $id
 * @property string $product_name
 * @property string $category
 * @property string|null $alias_name
 * @property string|null $model_name
 * @property string|null $model_no
 * @property string|null $image
 * @property string|null $description
 * @property string|null $purpose
 * @property string|null $vendor
 * @property int $different_income_category
 * @property float|null $income_account
 * @property float|null $selling_price
 * @property float|null $counter_price
 * @property float|null $distributor_price
 * @property float $govt_without_rc_price
 * @property float $industry_price
 * @property float $marine_product_price
 * @property float $rate_contract_price
 * @property float $private_lab_price
 * @property float $school_college_price
 * @property float $mrp
 * @property string|null $multiple_prices
 * @property string|null $selling_tax_rate
 * @property int $selling_inclusive_of_tax
 * @property float|null $mrp_margin
 * @property string|null $mrp_margin_type
 * @property int $diff_expense_category
 * @property string|null $expense_account
 * @property float|null $bying_price
 * @property int $buying_inclusive_tax
 * @property string|null $tax_rate
 * @property int $diff_currency
 * @property string|null $currency
 * @property float|null $default_currency_price
 * @property string|null $opening_stock
 * @property float|null $opening_rate_per_unit
 * @property string|null $product_code_sku
 * @property string|null $barcode
 * @property string|null $product_type
 * @property string|null $hsn_sac_code
 * @property int $show_inventory
 * @property int $show_screen_pos
 * @property int $show_after_subtotal
 * @property int $min_order_level
 * @property int $re_order_level
 * @property int $max_order_level
 * @property string $units
 * @property string $stock_unit
 * @property int $conversion_ratio
 * @property string $created_at
 * @property string $updated_at
 */
class Product extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'product';
    }

    /**
     * {@inheritdoc}
     */
    public $tax_wise;
    public $categorysearch;
    public $all;
    public function rules()
    {
        return [
            [['product_name','category'], 'required'],
            [['description', ], 'string'],
            [['all','hsn_sac_code','created_at', 'updated_at','tax_rate','categorysearch','tax_wise','product_code_sku','selling_tax_rate', 'govt_without_rc_price', 'industry_price', 'marine_product_price', 'rate_contract_price', 'private_lab_price', 'school_college_price', 'mrp', 'min_order_level', 're_order_level', 'max_order_level', 'units', 'conversion_ratio'], 'safe'],
            [['different_income_category', 'selling_inclusive_of_tax', 'diff_expense_category', 'buying_inclusive_tax', 'diff_currency', 'show_inventory', 'show_screen_pos', 'show_after_subtotal', 'min_order_level', 're_order_level', 'max_order_level',], 'integer'],
            [[ 'selling_price', 'counter_price', 'distributor_price', 'govt_without_rc_price', 'industry_price', 'marine_product_price', 'rate_contract_price', 'private_lab_price', 'school_college_price', 'mrp', 'mrp_margin', 'bying_price', 'default_currency_price', 'opening_rate_per_unit','conversion_ratio','stock_unit','on_create_stock'], 'number'],
            [[ 'selling_price', 'counter_price', 'distributor_price', 'govt_without_rc_price', 'industry_price', 'marine_product_price', 'rate_contract_price', 'private_lab_price', 'school_college_price', 'mrp', 'mrp_margin', 'bying_price', 'default_currency_price', 'opening_rate_per_unit','conversion_ratio'] ,'compare','compareValue'=>0,'operator'=> ">="],
            [[ 'selling_price', 'counter_price', 'distributor_price', 'govt_without_rc_price', 'industry_price', 'marine_product_price', 'rate_contract_price', 'private_lab_price', 'school_college_price', 'mrp', 'mrp_margin', 'bying_price', 'default_currency_price', 'opening_rate_per_unit','conversion_ratio'] ,'compare','compareValue'=>99999999,'operator'=> "<="],
            [['min_order_level', 're_order_level', 'max_order_level'] ,'compare','compareValue'=>0,'operator'=> ">="],
            [['category', 'alias_name', 'model_name', 'model_no', 'image', 'purpose', 'vendor', 'mrp_margin_type'], 'string', 'max' => 512],
            [['different_income_category'], 'my_required'],
            [['diff_expense_category'], 'my_required1'],
            [['multiple_prices'], 'string', 'max' => 1024],
            [['income_account'],'string','max'=>128],
	    [['product_name'],'string'],
            ['max_order_level','compare','compareAttribute'=>'min_order_level','operator'=>'>','message'=>'Maximum order level unit should be greator than minimum order level unit'], 
            //['mrp','compare','compareAttribute'=>'selling_price','operator'=>'>', 'type' => 'number'], 
            //['mrp','compare','compareAttribute'=>'bying_price','operator'=>'>=', 'type' => 'number'], 
           // ['selling_price','compare','compareAttribute'=>'bying_price','operator'=>'>=', 'type' => 'number'], 
            [['expense_account', 'currency', 'opening_stock', 'barcode', 'product_type',], 'string', 'max' => 128],
            [['units'], 'string', 'max' => 32],
            // [['stock_unit'],'integer'],
            ['product_name', 'unique', 'message' => 'This product name address has already been taken.'],

        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'product_name' => 'Product Name',
            'category' => 'Category',
            'alias_name' => 'Alias Name',
            'model_name' => 'Model Name',
            'model_no' => 'Model No',
            'image' => 'Image',
            'description' => 'Description',
            'purpose' => 'Purpose',
            'vendor' => 'Vendor',
            'different_income_category' => 'Different Income Category',
            'income_account' => 'Income Amount',
            'selling_price' => 'Selling Price',
            'counter_price' => 'Counter Price',
            'distributor_price' => 'Distributor Price',
            'govt_without_rc_price' => 'Govt Without Rc Price',
            'industry_price' => 'Industry Price',
            'marine_product_price' => 'Marine Product Price',
            'rate_contract_price' => 'Rate Contract Price',
            'private_lab_price' => 'Private Lab Price',
            'school_college_price' => 'School College Price',
            'mrp' => 'Mrp',
            'multiple_prices' => 'Multiple Prices',
            'selling_tax_rate' => 'Selling Tax Rate',
            'selling_inclusive_of_tax' => 'Selling Inclusive Of Tax',
            'mrp_margin' => 'Mrp Margin',
            'mrp_margin_type' => 'Mrp Margin Type',
            'diff_expense_category' => 'Diff Expense Category',
            'expense_account' => 'Expense Account',
            'bying_price' => 'Buying Price',
            'buying_inclusive_tax' => 'Buying Inclusive Tax',
            'tax_rate' => 'Tax Rate',
            'diff_currency' => 'Diff Currency',
            'currency' => 'Currency',
            'default_currency_price' => 'Default Currency Price',
            'opening_stock' => 'Opening Stock',
            'opening_rate_per_unit' => 'Opening Rate Per Unit',
            'product_code_sku' => 'Product Code Sku',
            'barcode' => 'Barcode',
            'product_type' => 'Product Type',
            'hsn_sac_code' => 'Hsn Sac Code',
            'show_inventory' => 'Show Inventory',
            'show_screen_pos' => 'Show Screen Pos',
            'show_after_subtotal' => 'Show After Subtotal',
            'min_order_level' => 'Min Order Level',
            're_order_level' => 'Re Order Level',
            'max_order_level' => 'Max Order Level',
            'units' => 'Units',
            'stock_unit' => 'Stock Unit',
            'conversion_ratio' => 'Conversion Ratio',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
        ];
    }
    public function my_required($attribute,$params)
    { if($this->different_income_category)
        $this->addError('income_account','Can not be blank');
    }
    public function my_required1($attribute,$params){
    if($this->diff_expense_category)
    $this->addError('expense_account','Can not be blank');
    }
}
