<?php

namespace backend\modules\master\models;

use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\master\models\Product;

/**
 * ProductSearch represents the model behind the search form of `backend\modules\master\models\Product`.
 */
class ProductSearch extends Product
{
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id', 'different_income_category', 'selling_inclusive_of_tax', 'diff_expense_category', 'buying_inclusive_tax', 'diff_currency', 'show_inventory', 'show_screen_pos', 'show_after_subtotal', 'min_order_level', 're_order_level', 'max_order_level', 'conversion_ratio'], 'integer'],
            [['product_name', 'category', 'alias_name', 'model_name', 'model_no', 'image', 'description', 'purpose', 'vendor', 'multiple_prices', 'selling_tax_rate', 'mrp_margin_type', 'expense_account', 'tax_rate', 'currency', 'opening_stock', 'product_code_sku', 'barcode', 'product_type', 'hsn_sac_code', 'units', 'stock_unit', 'created_at', 'updated_at'], 'safe'],
            [['income_account', 'selling_price', 'counter_price', 'distributor_price', 'govt_without_rc_price', 'industry_price', 'marine_product_price', 'rate_contract_price', 'private_lab_price', 'school_college_price', 'mrp', 'mrp_margin', 'bying_price', 'default_currency_price', 'opening_rate_per_unit'], 'number'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Product::find();

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id' => $this->id,
            'different_income_category' => $this->different_income_category,
            'income_account' => $this->income_account,
            'selling_price' => $this->selling_price,
            'counter_price' => $this->counter_price,
            'distributor_price' => $this->distributor_price,
            'govt_without_rc_price' => $this->govt_without_rc_price,
            'industry_price' => $this->industry_price,
            'marine_product_price' => $this->marine_product_price,
            'rate_contract_price' => $this->rate_contract_price,
            'private_lab_price' => $this->private_lab_price,
            'school_college_price' => $this->school_college_price,
            'mrp' => $this->mrp,
            'selling_inclusive_of_tax' => $this->selling_inclusive_of_tax,
            'mrp_margin' => $this->mrp_margin,
            'diff_expense_category' => $this->diff_expense_category,
            'bying_price' => $this->bying_price,
            'buying_inclusive_tax' => $this->buying_inclusive_tax,
            'diff_currency' => $this->diff_currency,
            'default_currency_price' => $this->default_currency_price,
            'opening_rate_per_unit' => $this->opening_rate_per_unit,
            'show_inventory' => $this->show_inventory,
            'show_screen_pos' => $this->show_screen_pos,
            'show_after_subtotal' => $this->show_after_subtotal,
            'min_order_level' => $this->min_order_level,
            're_order_level' => $this->re_order_level,
            'max_order_level' => $this->max_order_level,
            'conversion_ratio' => $this->conversion_ratio,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ]);

        $query->andFilterWhere(['like', 'product_name', $this->product_name])
            ->andFilterWhere(['like', 'category', $this->category])
            ->andFilterWhere(['like', 'alias_name', $this->alias_name])
            ->andFilterWhere(['like', 'model_name', $this->model_name])
            ->andFilterWhere(['like', 'model_no', $this->model_no])
            ->andFilterWhere(['like', 'image', $this->image])
            ->andFilterWhere(['like', 'description', $this->description])
            ->andFilterWhere(['like', 'purpose', $this->purpose])
            ->andFilterWhere(['like', 'vendor', $this->vendor])
            ->andFilterWhere(['like', 'multiple_prices', $this->multiple_prices])
            ->andFilterWhere(['like', 'selling_tax_rate', $this->selling_tax_rate])
            ->andFilterWhere(['like', 'mrp_margin_type', $this->mrp_margin_type])
            ->andFilterWhere(['like', 'expense_account', $this->expense_account])
            ->andFilterWhere(['like', 'tax_rate', $this->tax_rate])
            ->andFilterWhere(['like', 'currency', $this->currency])
            ->andFilterWhere(['like', 'opening_stock', $this->opening_stock])
            ->andFilterWhere(['like', 'product_code_sku', $this->product_code_sku])
            ->andFilterWhere(['like', 'barcode', $this->barcode])
            ->andFilterWhere(['like', 'product_type', $this->product_type])
            ->andFilterWhere(['like', 'hsn_sac_code', $this->hsn_sac_code])
            ->andFilterWhere(['like', 'units', $this->units])
            ->andFilterWhere(['like', 'stock_unit', $this->stock_unit]);

        return $dataProvider;
    }
}
