<?php

namespace backend\modules\master\models;

use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\models\UserClient;
use backend\modules\master\models\PurchaseOrder;

/**
 * PurchaseOrderSearch represents the model behind the search form of `backend\modules\master\models\PurchaseOrder`.
 */
class PurchaseOrderSearch extends PurchaseOrder
{
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id', 'suffix', 'is_allow_advance'], 'integer'],
            [['setting_type', 'vendor_name', 'sendor_gstin', 'bill_type', 'notes', 'delivery_address', 'supply_type', 'supply_attracts', 'currancy', 'point_of_supply', 'eligibity_of_itc', 'prefix', 'po_last', 'date', 'due_date', 'terms_of_payment', 'terms_and_condition', 'supplier_ref', 'other_ref', 'dispatch_through', 'destination', 'mode_of_payment', 'delivery_date', 'terms_of_delivery','total_amount','advance_amount','po_no_final'], 'safe'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params,array $accessed=null)
    {

        if($accessed == null)
        {
            $query = PurchaseOrder::find()->orderBy([
            'id' => SORT_DESC,
             ])->where(['is_deleted' =>0]);
        }
        else
        {
            $vendors = UserClient::find()->where(['user_id'=>$accessed])->andWhere(['client_type'=>'Vendor'])->all();
            $vendor_ids= [];
            $i = 0;
            foreach($vendors as $data)
            {
                $vendor_ids[$i] = $data->client_id;
                $i++;
            }
            $query = PurchaseOrder::find()->orderBy(['id' => SORT_DESC])->where(['in', 'vendor_name', $vendor_ids])->andWhere(['is_deleted' =>0]);
        }
        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id' => $this->id,
            'suffix' => $this->suffix,
            'date' => $this->date,
            'due_date' => $this->due_date,
            'is_allow_advance' => $this->is_allow_advance,
            'delivery_date' => $this->delivery_date,
        ]);

        $query->andFilterWhere(['like', 'setting_type', $this->setting_type])
            ->andFilterWhere(['like', 'vendor_name', $this->vendor_name])
            ->andFilterWhere(['like', 'sendor_gstin', $this->sendor_gstin])
            ->andFilterWhere(['like', 'bill_type', $this->bill_type])
            ->andFilterWhere(['like', 'notes', $this->notes])
            ->andFilterWhere(['like', 'delivery_adredss', $this->delivery_address])
            ->andFilterWhere(['like', 'supply_type', $this->supply_type])
            ->andFilterWhere(['like', 'supply_attracts', $this->supply_attracts])
            ->andFilterWhere(['like', 'currancy', $this->currancy])
            ->andFilterWhere(['like', 'point_of_supply', $this->point_of_supply])
            ->andFilterWhere(['like', 'eligibity_of_itc', $this->eligibity_of_itc])
            ->andFilterWhere(['like', 'prefix', $this->prefix])
            ->andFilterWhere(['like', 'po_last', $this->po_last])
            ->andFilterWhere(['like', 'terms_of_payment', $this->terms_of_payment])
            ->andFilterWhere(['like', 'terms_and_condition', $this->terms_and_condition])
            ->andFilterWhere(['like', 'supplier_ref', $this->supplier_ref])
            ->andFilterWhere(['like', 'other_ref', $this->other_ref])
            ->andFilterWhere(['like', 'dispatch_through', $this->dispatch_through])
            ->andFilterWhere(['like', 'destination', $this->destination])
            ->andFilterWhere(['like', 'mode_of_payment', $this->mode_of_payment])
            ->andFilterWhere(['like', 'total_amount', $this->total_amount])
            ->andFilterWhere(['like', 'advance_amount', $this->advance_amount])
            ->andFilterWhere(['like', 'po_no_final', $this->po_no_final])
            ->andFilterWhere(['like', 'terms_of_delivery', $this->terms_of_delivery]);

        return $dataProvider;
    }
}
