<?php

namespace backend\modules\reports\controllers;

use backend\modules\reports\models\OverdueInvoiceReportSearch;
use yii\web\Controller;
use Mpdf\Mpdf;
use Yii;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;

class OverdueInvoiceReportController extends Controller
{
    private function getAllDataProvider()
    {
        $searchModel = new OverdueInvoiceReportSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        // Disable pagination
        $dataProvider->pagination = false;
        return $dataProvider;
    }

    public function actionIndex()
    {
        $searchModel = new OverdueInvoiceReportSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        if (Yii::$app->request->post()) {
         $searchModel->load(Yii::$app->request->post());
         $exportType = Yii::$app->request->post('export_type');

         if ($exportType === 'export_print') {
            $dataProvider = $this->getAllDataProvider();
        
            // Initialize totals
            $inv_amt = 0;
            $pending_amt = 0;
            $paid_amt = 0;
        
            // Iterate through data to accumulate totals
            foreach ($dataProvider->models as $data) {
                    $inv_amt += $data->amount;
                    $pending_amt += $data->pending;
                    $paid_amt += $data->paid;
                }
            
                $pdfData = [
                    'dataProvider' => $dataProvider,
                    'is_customer' => $searchModel->is_customer,
                    'is_invoiceid' => $searchModel->is_invoiceid,
                    'is_mobile' => $searchModel->is_mobile,
                    'is_phone' => $searchModel->is_phone,
                    'is_date' => $searchModel->is_date,
                    'is_amt' => $searchModel->is_amt,
                    'is_paidamt' => $searchModel->is_paidamt,
                    'is_unpaidamt' => $searchModel->is_unpaidamt,
                    'is_duedate' => $searchModel->is_duedate,
                    'is_days' => $searchModel->is_days,
                    'is_executives' => $searchModel->is_executives,
                    'is_notes' => $searchModel->is_notes,
                    'is_terms' => $searchModel->is_terms,
                    'is_currentoutstanding' => $searchModel->is_currentoutstanding,
                    'is_overdue' => $searchModel->is_overdue,
                    'is_totaloutstanding' => $searchModel->is_totaloutstanding,
                    'inv_amt' => $inv_amt,
                    'pending_amt' => $pending_amt,
                    'paid_amt' => $paid_amt,
                ];
            
                $htmlContent = $this->renderPartial('/overdue-invoice-report/export-print', $pdfData);
            
                // Output the PDF directly to the browser
                return $htmlContent; // 'I' for inline display in browser
            } else {
                $dataProvider = $this->getAllDataProvider();
                $i = 65;
                $rowcount = 7;
                $phpExcel = new \PHPExcel();
                $phpExcel->getDefaultStyle()->getFont()->setName('Calibri');
                $phpExcel->getActiveSheet()->getStyle('D1')->getAlignment()->setWrapText(true);
                $phpExcel->getProperties()->setDescription("Excel SpreadSheet in PHP");
                $writer = \PHPExcel_IOFactory::createWriter($phpExcel, "Excel2007");
                $sheet = $phpExcel->getActiveSheet();

                $sheet->getCell('A1')->setValue('MOHAPATRA SCIENTIFIC PRIVATE LIMITED');
                $sheet->getCell('A2')->setValue('');
                $sheet->getCell('A3')->setValue('F2G/30, INDRADHANU MARKET, IRC VILLAGE,');
                $sheet->getCell('A4')->setValue('BHUBANESWAR, Odisha');
                $sheet->getCell('A5')->setValue('');
                $sheet->getCell('A6')->setValue('Statement Of Account');

                $sheet->getStyle('A1:S1')->getFont()->setBold(true)->setSize(12);
                $sheet->getStyle('A2:S2')->getFont()->setSize(11);
                $sheet->getStyle('A3:S3')->getFont()->setSize(11);
                $sheet->getStyle('A4:S4')->getFont()->setSize(11);
                $sheet->getStyle('A5:S5')->getFont()->setSize(11);
                $sheet->getStyle('A6:S6')->getFont()->setBold(true)->setSize(11);

                $sheet->getColumnDimension('A')->setWidth(40);
                $sheet->getColumnDimension('B')->setWidth(30);
                $sheet->getColumnDimension('C')->setWidth(20);
                $sheet->getColumnDimension('D')->setWidth(20);

                $sheet->mergeCells('A1:Q1');
                $sheet->mergeCells('A2:Q2');
                $sheet->mergeCells('A3:Q3');
                $sheet->mergeCells('A4:Q4');
                $sheet->mergeCells('A5:Q5');
                $sheet->mergeCells('A6:Q6');

                if ($searchModel->is_customer) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Customer');
                    $i++;
                }
                if ($searchModel->is_mobile) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Mobile No');
                    $i++;
                }
                if ($searchModel->is_phone) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Phone No.');
                    $i++;
                }
                if ($searchModel->is_invoiceid) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Invoice No.');
                    $i++;
                }
                if ($searchModel->is_date) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Date');
                    $i++;
                }
                if ($searchModel->is_amt) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Amount');
                    $i++;
                }
                if ($searchModel->is_paidamt) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Paid');
                    $i++;
                }
                if ($searchModel->is_unpaidamt) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Pending');
                    $i++;
                }
                if ($searchModel->is_duedate) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Due Date');
                    $i++;
                }
                if ($searchModel->is_days) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Days Crossed');
                    $i++;
                }
                if ($searchModel->is_executives) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Executive');
                    $i++;
                }
                if ($searchModel->is_notes) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Notes');
                    $i++;
                }
                if ($searchModel->is_terms) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Terms');
                    $i++;
                }
                if ($searchModel->is_currentoutstanding) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Current Outstanding');
                    $i++;
                }
                if ($searchModel->is_overdue) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Over Due');
                    $i++;
                }
                if ($searchModel->is_totaloutstanding) {
                    $sheet->setCellValue(chr($i) . $rowcount, 'Total Outstanding');
                    $i++;
                }

                $row = 8;
                $inv_amt = 0;
                $pending_amt = 0;
                $paid_amt = 0;
                $amt_col = '';
                $paid_col = '';
                $pending_col = '';
                $curr_col = '';
                $outstanding_col = '';
                $overdue_col = '';

                foreach ($dataProvider->models as $data) {
                    $inv_amt += $data->amount;
                    $pending_amt += $data->pending;
                    $paid_amt += $data->paid;
                    $i = 65; // Reset column to 'A'

                    // Assuming dataProvider provides the complete data, including customer info
                    $sheet->getStyle('A' . $row)->getAlignment()->setWrapText(true);

                    if ($searchModel->is_customer) {
                        $sheet->getStyle(chr($i) . $row)->getAlignment()->setWrapText(true);
                        $sheet->setCellValue(chr($i++) . $row, $data->business_name);
                    }
                    if ($searchModel->is_mobile) $sheet->setCellValue(chr($i++) . $row, $data->mobile);
                    if ($searchModel->is_phone) $sheet->setCellValue(chr($i++) . $row, $data->phone);
                    if ($searchModel->is_invoiceid) $sheet->setCellValue(chr($i++) . $row, $data->invoice_id);
                    if ($searchModel->is_date) $sheet->setCellValue(chr($i++) . $row, $data->date);
                    if ($searchModel->is_amt) {
                        $sheet->setCellValue(chr($i) . $row, $data->amount);
                        if (empty($amt_col)) $amt_col = chr($i);
                        $i++;
                    }
                    if ($searchModel->is_paidamt) {
                        $sheet->setCellValue(chr($i) . $row, $data->paid);
                        if (empty($paid_col)) $paid_col = chr($i);
                        $i++;
                    }
                    if ($searchModel->is_unpaidamt) {
                        $sheet->setCellValue(chr($i) . $row, $data->pending);
                        if (empty($pending_col)) $pending_col = chr($i);
                        $i++;
                    }
                    if ($searchModel->is_duedate) $sheet->setCellValue(chr($i++) . $row, $data->due_date);
                    if ($searchModel->is_days) $sheet->setCellValue(chr($i++) . $row, (string)$data->due_days);
                    if ($searchModel->is_executives) $sheet->setCellValue(chr($i++) . $row, $data->executive);
                    if ($searchModel->is_notes) $sheet->setCellValue(chr($i++) . $row, 'Notes');
                    if ($searchModel->is_terms) $sheet->setCellValue(chr($i++) . $row, 'Terms');
                    if ($searchModel->is_currentoutstanding) {
                        $sheet->setCellValue(chr($i) . $row, '0.00');
                        if (empty($curr_col)) $curr_col = chr($i);
                        $i++;
                    }
                    if ($searchModel->is_overdue) {
                        $sheet->setCellValue(chr($i) . $row, $data->pending);
                        if (empty($overdue_col)) $overdue_col = chr($i);
                        $i++;
                    }
                    if ($searchModel->is_totaloutstanding) {
                        $sheet->setCellValue(chr($i) . $row, $data->pending);
                        if (empty($outstanding_col)) $outstanding_col = chr($i);
                        $i++;
                    }

                    $row++;
                }

                $sheet->getStyle('A1:Z' . $row)->getFont()->setSize(10);
                $sheet->getStyle('A7:Z7')->getFont()->setBold(true)->setSize(10);
                $sheet->getStyle('A7:Z7')->getAlignment()->setHorizontal(\PHPExcel_Style_Alignment::HORIZONTAL_CENTER);

                $sheet->setCellValue('A' . $row, 'Total');
                $sheet->getStyle('A' . $row)->getFont()->setBold(true);

                if (!empty($amt_col)) {
                    $sheet->setCellValue($amt_col . $row, (string)$inv_amt);
                }
                if (!empty($paid_col)) {
                    $sheet->setCellValue($paid_col . $row, (string)$paid_amt);
                }
                if (!empty($pending_col)) {
                    $sheet->setCellValue($pending_col . $row, (string)$pending_amt);
                }
                if (!empty($curr_col)) {
                    $sheet->setCellValue($curr_col . $row, (string)$inv_amt);
                }
                if (!empty($overdue_col)) {
                    $sheet->setCellValue($overdue_col . $row, (string)$paid_amt);
                }
                if (!empty($outstanding_col)) {
                    $sheet->setCellValue($outstanding_col . $row, (string)$pending_amt);
                }

                $writer->save(Yii::$app->basePath . '/web/overdue_invoice_report.xlsx');
                return Yii::$app->response->sendFile(Yii::$app->basePath . '/web/overdue_invoice_report.xlsx');
            }
        }

        return $this->render('index', [
            'model' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
}