<?php

namespace backend\modules\reports\controllers;

use backend\modules\master\models\Category;
use backend\modules\master\models\Product;
use backend\modules\master\models\Vendor;
use backend\modules\reports\models\SalesFastSlowMovingReport;
use backend\modules\reports\models\SalesFastSlowMovingReportSearch;
use Mpdf\Mpdf;
use yii\data\ActiveDataProvider;
use yii\helpers\ArrayHelper;
use Yii;
use PHPExcel;
use PHPExcel_IOFactory;

class SalesMovingProductController extends \yii\web\Controller
{

    public function actionIndex($print = null, $excel = null)
    {
        $searchModel = new SalesFastSlowMovingReportSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        if ($print !== null) {
            $dataProvider->pagination = false;
            return $this->renderPartial('/sales-moving-product/print', [
                'dataProvider' => $dataProvider,
                'model' => $searchModel,
            ]);
        }

        if ($excel !== null) {
            $dataProvider->pagination = false; // Disable pagination for exporting
            $this->actionExcelReport($dataProvider);
            return;
        }

        return $this->render('index', [
            'model' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    public function actionVendordetails($searchTerm = null)
    {
        if (!$searchTerm) {
            $product = Vendor::find()->limit(10)->all();
        } else {
            $product = Vendor::find()->where(["like", "business_name", $searchTerm])->limit(10)->all();
        }

        $productlist = ArrayHelper::map($product, 'business_name', 'business_name');
        return json_encode($productlist);
    }

    public function actionProductdetails($searchTerm = null)
    {
        if (!$searchTerm) {
            $product = Category::find()->limit(10)->all();
        } else {
            $product = Category::find()->where(["like", "name", $searchTerm])->limit(10)->all();
        }
        $productlist = ArrayHelper::map($product, 'id', 'name');
        return json_encode($productlist);
    }

    public function actionExcelReport($data = null)
    {
        $dataProvider = $data;

        $phpExcel = new PHPExcel;
        $phpExcel->getDefaultStyle()->getFont()->setName('Calibri');
        $phpExcel->getProperties()->setDescription("Excel Spreadsheet in PHP");
        $sheet = $phpExcel->getActiveSheet();

        // Set title and header styles
        $sheet->setCellValue('A1', 'MOHAPATRA SCIENTIFIC PRIVATE LIMITED')
            ->setCellValue('A2', 'F2G/30, INDRADHANU MARKET, IRC VILLAGE,')
            ->setCellValue('A3', 'BHUBANESWAR, Odisha')
            ->setCellValue('A4', 'Purchase Report');
        $sheet->getStyle('A1:D4')->getFont()->setBold(true)->setSize(11);
        $sheet->getColumnDimension('A')->setWidth(50);
        $sheet->getColumnDimension('B')->setWidth(40);
        $sheet->getColumnDimension('C')->setWidth(20);
        $sheet->getColumnDimension('D')->setWidth(20);
        $sheet->setCellValue('A6', 'Product Name')
            ->setCellValue('B6', 'Product Description')
            ->setCellValue('C6', 'Barcode')
            ->setCellValue('D6', 'Product Sold');

        $row = 7;
        $total_qty = 0;
        $total_items = 0;

        foreach ($dataProvider->getModels() as $model) {
            $total_qty += $model->product_sold;
            $total_items++;
            $barcode = $model->barcode; // Directly get barcode from the view model
            $sheet->setCellValue('A' . $row, $model->product_name)
                ->setCellValue('B' . $row, $model->description)
                ->setCellValue('C' . $row, $barcode)
                ->setCellValue('D' . $row, (string)$model->product_sold);
            $row++;
        }
        $sheet->setCellValue('C' . $row, 'Total Items Sold:' . $total_items)
            ->setCellValue('D' . $row, (string)$total_qty);

        header('Content-type: application/vnd.ms-excel');
        header('Content-Disposition: attachment; filename="Sales-Fast-Slow-moving-product.xlsx"');
        $writer = PHPExcel_IOFactory::createWriter($phpExcel, "Excel2007");
        $writer->save('php://output');
        exit();
    }
}
