<?php

namespace backend\modules\reports\models;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;

/**
 * OverdueInvoiceReportSearch represents the model behind the search form of `backend\modules\reports\models\OverdueInvoiceReport`.
 */
class OverdueInvoiceReportSearch extends OverdueInvoiceReport
{
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['date', 'due_date', 'from_date', 'to_date', 'c_name', 'creator', 'exe', 'c_type', 'order', 'is_invoiceid', 'is_customer', 'is_mobile', 'is_phone', 'is_date', 'is_amt', 'is_paidamt', 'is_unpaidamt', 'is_duedate', 'is_days', 'is_executives', 'is_notes', 'is_terms', 'is_currentoutstanding', 'is_overdue', 'is_totaloutstanding'], 'safe'],
            [['amount', 'paid', 'pending'], 'number'],
            [['due_days'], 'integer'],
            [['customer_name', 'executive', 'invoice_id', 'status', 'notes', 'terms', 'current_outstanding'], 'string', 'max' => 254],
            [['due_days_crossed'], 'string', 'max' => 19],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = OverdueInvoiceReport::find();

        // Add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 20,
            ],
            'sort' => [
                'defaultOrder' => [
                    'due_date' => SORT_DESC,
                ],
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // Uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // Grid filtering conditions
        $query->andFilterWhere([
            'amount' => $this->amount,
            'paid' => $this->paid,
            'pending' => $this->pending,
            'due_days' => $this->due_days,
            'date' => $this->date,
            'due_date' => $this->due_date,
        ]);

        $query->andFilterWhere(['like', 'customer_name', $this->customer_name])
            ->andFilterWhere(['like', 'executive', $this->executive])
            ->andFilterWhere(['like', 'invoice_id', $this->invoice_id])
            ->andFilterWhere(['like', 'status', $this->status])
            ->andFilterWhere(['like', 'due_days_crossed', $this->due_days_crossed])
            ->andFilterWhere(['like', 'notes', $this->notes])
            ->andFilterWhere(['like', 'terms', $this->terms]);

        // Date range filtering
        if (!empty($this->from_date) && !empty($this->to_date)) {
            $query->andFilterWhere(['between', 'date', $this->from_date, $this->to_date]);
        }

        return $dataProvider;
    }
}
