<?php
namespace backend\modules\reports\models;

use yii\base\Model;
use yii\data\ActiveDataProvider;

/**
 * PurchaseVendorLedgerSearch represents the model behind the search form of `backend\modules\reports\models\PurchaseVendorLedger`.
 */
class PurchaseVendorLedgerSearch extends PurchaseVendorLedger
{
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['Date', 'from_date', 'to_date', 'details_from_date', 'details_to_date'], 'safe'],
            [['total_debit_amount', 'total_credit_amount', 'details_total_from', 'details_total_to'], 'number'],
            [['vendor_type', 'sort_by', 'balance', 'group', 'type', 'ledger_id', 'details_type'], 'string', 'max' => 254],
            [['ledgerhead_id', 'details_user'], 'string', 'max' => 255],
            [['details_notes', 'details_ref'], 'string'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = PurchaseVendorLedger::find();

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 20, // Adjust as needed
            ],
            'sort' => [
                'defaultOrder' => [
                    'Date' => SORT_DESC,
                ],
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere(['like', 'vendor_type', $this->vendor_type])
            ->andFilterWhere(['like', 'ledgerhead_id', $this->ledgerhead_id])
            ->andFilterWhere(['>=', 'Date', $this->from_date])
            ->andFilterWhere(['<=', 'Date', $this->to_date])
            ->andFilterWhere(['>=', 'details_from_date', $this->details_from_date])
            ->andFilterWhere(['<=', 'details_to_date', $this->details_to_date])
            ->andFilterWhere(['>=', 'total_debit_amount', $this->details_total_from])
            ->andFilterWhere(['<=', 'total_credit_amount', $this->details_total_to])
            ->andFilterWhere(['like', 'details_notes', $this->details_notes])
            ->andFilterWhere(['like', 'details_user', $this->details_user])
            ->andFilterWhere(['like', 'details_ref', $this->details_ref])
            ->andFilterWhere(['like', 'type', $this->type])
            ->andFilterWhere(['like', 'group', $this->group])
            ->andFilterWhere(['like', 'sort_by', $this->sort_by])
            ->andFilterWhere(['like', 'balance', $this->balance])
            ->andFilterWhere(['like', 'ledger_id', $this->ledger_id])
            ->andFilterWhere(['like', 'details_type', $this->details_type]);

        return $dataProvider;
    }
}
