<?php

namespace backend\modules\reports\models;

use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\reports\models\SalesFastSlowMovingReport;

class SalesFastSlowMovingReportSearch extends SalesFastSlowMovingReport
{
    public $from_date;
    public $to_date;
    public $v_name;
    public $cat;
    public $type;
    public $barcode; // Add this line to include the barcode attribute

    public function rules()
    {
        return [
            [['from_date', 'to_date'], 'safe'],
            [['v_name', 'barcode'], 'string'], // Include barcode in validation rules
            [['cat', 'type'], 'integer'],
        ];
    }

    public function search($params)
    {
        $query = self::find()
            ->alias('s')
            ->select([
                's.date',
                's.product_id',
                's.product_name',
                's.description',
                's.product_sold',
                's.units',
                's.category',
                's.vendor_name',
                's.vendor_id',
                's.category_id',
                's.barcode', // Add barcode to select statement
            ])
            ->groupBy([
                's.date',
                's.product_id',
                's.product_name',
                's.description',
                's.product_sold',
                's.units',
                's.category',
                's.vendor_name',
                's.vendor_id',
                's.category_id',
                's.barcode' // Include all selected columns in group by clause
            ]);

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 20, // Adjust page size if needed
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            return $dataProvider;
        }

        // Apply filters
        $query->andFilterWhere(['like', 's.vendor_name', $this->v_name])
              ->andFilterWhere(['between', 's.date', $this->from_date, $this->to_date])
              ->andFilterWhere(['s.category_id' => $this->cat]);

        // // Order by product_sold based on type
        // if ($this->type == 1) {
        //     $query->orderBy(['s.product_sold' => SORT_DESC]);
        // } else {
        //     $query->orderBy(['s.product_sold' => SORT_ASC]);
        // }

        return $dataProvider;
    }
}