<?php

namespace backend\modules\reports\models;

use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\reports\models\VendorLedgerOverview;

class VendorLedgerOverviewSearch extends VendorLedgerOverview
{
    public $from_date;
    public $to_date;
    public $order_by;
    public $ledger_balance;
    public $type;
    public $group;
    public $sort_by;
    public $balance;
    public $bs_name;
    public $vendor_type; // Ensure this is included

    public function rules()
    {
        return [
            [['Date', 'from_date', 'to_date', 'order_by', 'ledger_balance', 'type', 'group', 'sort_by', 'balance', 'bs_name', 'vendor_type'], 'safe'],
            [['total_debit_amount', 'total_credit_amount'], 'number'],
            [['vendor_type', 'business_name', 'ledgerhead_id'], 'string', 'max' => 254],
        ];
    }

    public function scenarios()
    {
        return Model::scenarios();
    }

    public function search($params)
    {
        $query = VendorLedgerOverview::find();

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 20,
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            return $dataProvider;
        }

        // Filtering conditions
        $query->andFilterWhere(['like', 'vendor_type', $this->type])
              ->andFilterWhere(['like', 'business_name', $this->bs_name])
              ->andFilterWhere(['between', 'Date', $this->from_date, $this->to_date]);

        if ($this->balance) {
            if ($this->balance == 'Non-zero Balance') {
                $query->andWhere(['!=', 'total_debit_amount', new \yii\db\Expression('total_credit_amount')]);
            } elseif ($this->balance == 'Zero Balance') {
                $query->andWhere(['=', 'total_debit_amount', new \yii\db\Expression('total_credit_amount')]);
            }
        }

        // Sorting condition
        if ($this->order_by) {
            if ($this->order_by == 'Acc ID Asc') {
                $query->orderBy(['ledgerhead_id' => SORT_ASC]);
            } elseif ($this->order_by == 'Acc ID Desc') {
                $query->orderBy(['ledgerhead_id' => SORT_DESC]);
            }
        } else {
            $query->orderBy(['business_name' => SORT_ASC]);
        }

        return $dataProvider;
    }
}
