<?php

namespace backend\modules\users\controllers;

use Yii;
use common\models\User;
use backend\modules\users\models\AccountingJournal;
use backend\modules\master\models\AccountingLedger;
use backend\modules\master\models\GroupName;
use backend\modules\users\models\JournalDebitCredit;
use backend\modules\users\models\AccountingJournalSearch;
use backend\modules\users\models\AccountingDetails;
use backend\modules\users\models\JournalInvoicesbills;
use backend\modules\master\models\Customer;
use backend\modules\master\models\Vendor;
use backend\modules\users\models\Invoice;
use backend\modules\users\models\PurchaseBill;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\helpers\ArrayHelper;
use Mpdf\Mpdf;
use yii\data\ActiveDataProvider;
use yii2tech\spreadsheet\Spreadsheet;
use yii\web\UploadedFile;
use yii\helpers\Html;
use yii\helpers\Url;
/**
 * AccountingJournalController implements the CRUD actions for AccountingJournal model.
 */
class AccountingJournalController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all AccountingJournal models.
     * @return mixed
     */
    public function actionIndex()
    {
        Yii::$app->view->params['active']=105;
        $searchModel = new AccountingJournalSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $model=new AccountingJournal();
        $account=AccountingLedger::find()->all();
        $accountlist=ArrayHelper::map($account, 'accounting_ledger_id', 'name');
        $user=User::find()->all();
        $username=ArrayHelper::map($user, 'id', 'username');
        if ($model->load(Yii::$app->request->get()) ) {
            $query=AccountingJournal::find()->where(['is_deleted'=>0]);
            $query->andFilterWhere(['between', 'date', $model->from_date,$model->to_date])
            ->andFilterWhere(['like', 'prefix', $model->prefix])
            ->andFilterWhere(['like', 'suffix', $model->suffix])
            ->andFilterWhere(['like', 'jv_no', $model->journal])
            ->andFilterWhere(['like', 'journal_type', $model->journaltype])
            ->andFilterWhere(['like', 'notes', $model->notes])
            ->andFilterWhere(['like', 'updated_by', $model->user_name]);  
            if($model->account){
                $accountlists=JournalDebitCredit::find()->where(['account_id'=>$model->account,'is_deleted'=>0])->groupBy(['journal_id'])->all();
                $accountid=ArrayHelper::map($accountlists, 'journal_id','journal_id');
                $query->andFilterWhere(['in', 'id', $accountid]) ; 
            }  
            $dataProvider = new ActiveDataProvider([
                'query' => $query,
                'sort'=> ['defaultOrder' => ['id' => SORT_DESC]],
            ]);
        }
        return $this->render('index', [
            'model'=>$model,
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'account' => $accountlist,
            'username' => $username,
        ]);
    }

    /**
     * Displays a single AccountingJournal model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        Yii::$app->view->params['active']=105;
        $data=JournalDebitCredit::find()->where(['journal_id'=>$id,'is_deleted'=>0])->all();
        return $this->render('view', [
            'model' => $this->findModel($id),
            'data'=>$data,
        ]);
    }

    /**
     * Creates a new AccountingJournal model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        Yii::$app->view->params['active'] = 105;
        $model = new AccountingJournal();
        $account = AccountingLedger::find()->all();
        $accountlist = ArrayHelper::map($account, 'accounting_ledger_id', 'name');
        $count = AccountingJournal::find()->count();
        $oldimage = $model->document_name;
        if ($model->load(Yii::$app->request->post())) {
            $model->updated_by = Yii::$app->user->identity->id;
            $model->jv_no = $count ? AccountingJournal::find()->orderby(['id' => SORT_DESC])->one()->id + 1 : 1;
            $model->document_name = UploadedFile::getInstance($model, 'document_name');
            if ($model->document_name) {
                $nameimage = (new \DateTime())->format('u');
                $model->document_name->saveAs('usersdocument/accounting_journal/' . $nameimage . '.' . $model->document_name->extension);
                $model->document_name = $nameimage . '.' . $model->document_name->extension;
            }
            if ($model->save()) {
                $data = Yii::$app->request->post();
                $debit_credit = array();
                for ($i = 1; $i <= $data['accountcount']; $i++) {
                    $val = new JournalDebitCredit();
                    // print_r('ddd');
                    // print_r(Yii::$app->request->post('account'.($i)));
                    $val->journal_id = $model->id;
                    $val->account_id = Yii::$app->request->post('account' . ($i));
                    $val->debit_amount = Yii::$app->request->post('debit' . ($i));
                    $val->credit_amount = Yii::$app->request->post('credit' . ($i));
                    $val->remarks = Yii::$app->request->post('remark' . ($i));
                    $val->save();
                    array_push($debit_credit, $val->id);
                }
                //  print_r($debit_credit);
                //     die();

                if (Yii::$app->request->post('Bill')) {
                    $billdata = Yii::$app->request->post()['Bill'];
                    // print_r($billdata);
                    // die();
                    foreach ($billdata as $value) {
                        if ($value['from'] == 'customer' && $value['amount'] >= 0) {
                            $bill = Invoice::find()->where(['invoice_id' => $value['bill_id']])->one();
                            $journaladjust = new JournalInvoicesbills();
                            $journaladjust->invoice_id = $value['bill_id'];
                            $journaladjust->journal_id = $model->id;
                            if($value['amount']!='')
                            {
                                $journaladjust->invoice_pay_amount = $value['amount'];
                            }
                            else{
                                $journaladjust->invoice_pay_amount = 0;
                            }
                            if($value['tdsamount']!='')
                            {
                                $journaladjust->invoice_tds_amount = $value['tdsamount'];
                            }
                            else{
                                $journaladjust->invoice_tds_amount = 0;
                            }
                            
                            $journaladjust->invoice_notes = $value['notes'];
                            $journaladjust->journal_debit_credit_id = $debit_credit[0];
                            $journaladjust->bill_type = 'INV';
                            $journaladjust->invoice_amount = $bill->total_price;
                            $journaladjust->invoice_date = $bill->date;
                            $journaladjust->save(false);

                            $bill->pending_amount = ($bill->pending_amount - ($journaladjust->invoice_pay_amount + $journaladjust->invoice_tds_amount));
                            $bill->save(false);
                        } else if ($value['from'] == 'vendor' && $value['amount'] >= 0) {
                            $bill = PurchaseBill::find()->where(['full_bill_name' => $value['bill_id']])->one();
                            $journaladjust = new JournalInvoicesbills();
                            $journaladjust->invoice_id = $value['bill_id'];
                            $journaladjust->journal_id = $model->id;
                            if($value['amount']!='')
                            {
                                $journaladjust->invoice_pay_amount = $value['amount'];
                            }
                            else{
                                $journaladjust->invoice_pay_amount = 0;
                            }
                            if($value['tdsamount']!='')
                            {
                                $journaladjust->invoice_tds_amount = $value['tdsamount'];
                            }
                            else{
                                $journaladjust->invoice_tds_amount = 0;
                            }
                            $journaladjust->invoice_notes = $value['notes'];
                            $journaladjust->journal_debit_credit_id = $debit_credit[0];
                            $journaladjust->bill_type = 'BILL';
                            $journaladjust->invoice_amount = $bill->total;
                            $journaladjust->invoice_date = $bill->date;
                            $journaladjust->save(false);

                            $bill->pending_amount = ($bill->pending_amount - ($journaladjust->invoice_pay_amount + $journaladjust->invoice_tds_amount));
                            $bill->save(false);
                        }
                    }
                }

                if (Yii::$app->request->post('Bill1')) {
                    $billdata = Yii::$app->request->post()['Bill1'];
                    $billdata = Yii::$app->request->post()['Bill1'];
                    foreach ($billdata as $value) {
                        if ($value['from'] == 'customer' && $value['amount'] > 0) {
                            $bill = Invoice::find()->where(['invoice_id' => $value['bill_id']])->one();
                            $journaladjust = new JournalInvoicesbills();
                            $journaladjust->invoice_id = $value['bill_id'];
                            $journaladjust->journal_id = $model->id;
                            if($value['amount']!='')
                            {
                                $journaladjust->invoice_pay_amount = $value['amount'];
                            }
                            else{
                                $journaladjust->invoice_pay_amount = 0;
                            }
                            if($value['tdsamount']!='')
                            {
                                $journaladjust->invoice_tds_amount = $value['tdsamount'];
                            }
                            else{
                                $journaladjust->invoice_tds_amount = 0;
                            }
                            $journaladjust->invoice_notes = $value['notes'];
                            $journaladjust->journal_debit_credit_id = $debit_credit[1];
                            $journaladjust->bill_type = 'INV';
                            $journaladjust->invoice_amount = $bill->total_price;
                            $journaladjust->invoice_date = $bill->date;
                            $journaladjust->save(false);

                            $bill->pending_amount = ($bill->pending_amount - ($journaladjust->invoice_pay_amount + $journaladjust->invoice_tds_amount));
                            $bill->save(false);
                        } else if ($value['from'] == 'vendor' && $value['amount'] > 0) {
                            $bill = PurchaseBill::find()->where(['full_bill_name' => $value['bill_id']])->one();
                            $journaladjust = new JournalInvoicesbills();
                            $journaladjust->invoice_id = $value['bill_id'];
                            $journaladjust->journal_id = $model->id;
                            if($value['amount']!='')
                            {
                                $journaladjust->invoice_pay_amount = $value['amount'];
                            }
                            else{
                                $journaladjust->invoice_pay_amount = 0;
                            }
                            
                            if($value['tdsamount']!='')
                            {
                                $journaladjust->invoice_tds_amount = $value['tdsamount'];
                            }
                            else{
                                $journaladjust->invoice_tds_amount = 0;
                            }
                            $journaladjust->invoice_notes = $value['notes'];
                            $journaladjust->journal_debit_credit_id = $debit_credit[1];
                            $journaladjust->bill_type = 'BILL';
                            $journaladjust->invoice_amount = $bill->total;
                            $journaladjust->invoice_date = $bill->date;
                            $journaladjust->save(false);

                            $bill->pending_amount = ($bill->pending_amount - ($journaladjust->invoice_pay_amount + $journaladjust->invoice_tds_amount));
                            $bill->save(false);
                        }
                    }
                }




                Yii::$app->getSession()->setFlash('success', 'Created Successfully');
                if (Yii::$app->request->post('print')) {
                }
                return $this->redirect(['index']);
            }
        }
        return $this->render('_form', [
            'model' => $model,
            'update' => 0,
            'datalist' => [],
            'productlist' => [],
            'accountlist' => $accountlist,
            'count' => $count,
        ]);
    }

    /**
     * Updates an existing AccountingJournal model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        Yii::$app->view->params['active']=105;
        $model = $this->findModel($id);
        if($model->is_deleted)
        throw new NotFoundHttpException('The requested page does not exist.');
        $count=AccountingJournal::find()->count();
        $data=JournalDebitCredit::find()->where(['journal_id'=>$id,'is_deleted'=>0])->all();
        foreach($data as $index=>$value){
            $data[$index]['id']=AccountingLedger::find()->where(['accounting_ledger_id'=>$value->account_id])->one()->name;
        }
        $account=AccountingLedger::find()->all();
        $accountlist=ArrayHelper::map($account, 'accounting_ledger_id', 'name');
        $oldimage=$model->document_name;
        $doc=JournalDebitCredit::find()->where(['journal_id'=>$id,'is_deleted'=>0])->all();
        if ($model->load(Yii::$app->request->post()) ) {
            $model->document_name = UploadedFile::getInstance($model,'document_name');
            if($model->document_name){
            $nameimage=(new \DateTime())->format('u');
            $model->document_name->saveAs('usersdocument/accounting_journal/' .$nameimage.'.'.$model->document_name->extension);
            $model->document_name=$nameimage. '.' . $model->document_name->extension;
            }else{
                $model->document_name=$oldimage;
            }
            $data=Yii::$app->request->post();
            JournalDebitCredit::deleteAll(['journal_id'=>$id,'is_deleted'=>0]);
            $model->updated_by=Yii::$app->user->identity->id;
            if($model->save()){ 
            for($i=1;$i<=$data['accountcount'];$i++){
                $val=new JournalDebitCredit();
                $val->journal_id=$model->id;
                $val->account_id=Yii::$app->request->post('account'.($i));
                $val->debit_amount=Yii::$app->request->post('debit'.($i));
                $val->credit_amount=Yii::$app->request->post('credit'.($i));
                $val->remarks=Yii::$app->request->post('remark'.($i));
                $val->save();
                }
                Yii::$app->getSession()->setFlash('success', 'Updated Successfully');
                if(Yii::$app->request->post('print')){
                    
                }
                return $this->redirect(['index']);
        }
    }

        return $this->render('_form', [
            'model' => $model,
            'update'=>1,
            'datalist'=>$data,
            'accountlist'=>$accountlist,
            'count'=>$count,
        ]);
    }
    public function actionFindledger($searchTerm=null)
    {   
        if(!$searchTerm)
        $ledgername=AccountingLedger::find()->limit(10)->all();
        else
        $ledgername=AccountingLedger::find()->where(["like","name",$searchTerm])->limit(10)->all();

        // $ledgernamelist=ArrayHelper::map($ledgername, 'accounting_ledger_id', 'name');

        // $ledgernamelist = ArrayHelper::map($ledgername, 'accounting_ledger_id', function ($model) {
        //     return $model['name'] . '(' . $model['group_name_id'] . ')';
        // });
        $ledgernamelist = ArrayHelper::map($ledgername, 'accounting_ledger_id', function ($model) {
            // Assuming you have a GroupModel that represents the table with the group names
            $groupModel = GroupName::findOne(['group_name_id' => $model['group_name_id']]);
            $groupName = $groupModel ? $groupModel->name_group : 'Unknown Group';
            return $model['name'] . '(' . $groupName . ')';
        });


        return json_encode($ledgernamelist);
    }
    public function actionDelete($id=null)
    {
        if($id==null)
        {
            $ids=Yii::$app->request->post('data');
            if($ids){
            foreach($ids as $id){
            $document=JournalDebitCredit::find()->where(['journal_id'=>$id])->all();
            foreach($document as $value){$value->is_deleted=1;$value->save();}
            $data=$this->findModel($id);
            $data->is_deleted=1;$data->updated_by=Yii::$app->user->identity->id;$data->save();
            }
            }
        }
        else
        {
            $data=$this->findModel($id);
            $data->is_deleted=1;$data->updated_by=Yii::$app->user->identity->id;$data->save();
            $document=JournalDebitCredit::find()->where(['journal_id'=>$id])->all();
            foreach($document as $value){$value->is_deleted=1;$value->save();}
        }
        Yii::$app->getSession()->setFlash('success', 'Deleted Successfully');
        return $this->redirect(['index']);
    }
    public function actionExcelExport($detail=null)
    {
         Yii::$app->view->params['active']=105;
        $dataProvider = new ActiveDataProvider([
            'query' => AccountingJournal::find()->where(['is_deleted'=>0])->orderBy(['id' => SORT_DESC]),
        ]);
        if($detail){
    $exporter = new Spreadsheet([
        'dataProvider' => $dataProvider,
        'columns' => [
            [
                'label'=>'Journal #',
               'attribute' => 'jv_no',
               'value' => function ($data) {
                return $data->jv_no;
               }
            ],
            'date:date',
            [
                'label'=>'Credit Account',
               'attribute' => 'total_credit',
               'value' => function ($data) {
                return $data->total_credit;
               }
            ],
            [
                'label'=>'Debit Account',
               'attribute' => 'total_debit',
               'value' => function ($data) {
                return $data->total_debit;
               }
            ],

	     [
                        'label'=>'From',
                        'value' => function ($data) {
                         $userdetls = JournalDebitCredit::find()->where(['journal_id'=>$data->id])->all();
                         foreach ($userdetls as $key => $value) {
                             if($value->debit_amount!=null)
                             {
                                  if($value->debit_amount!=null)
                             {
                                 $us = AccountingDetails::find()->where(['transaction_id'=>'J'.$data->id])->andWhere(['accounting_type'=>'Debit'])->one();
                                 return $us->ledgerhead_id;
                             }
                             }
                         }
                        }
                     ],
                     [
                         'label'=>'To',
                        'value' => function ($data) {
                         $userdetls = JournalDebitCredit::find()->where(['journal_id'=>$data->id])->all();
                         foreach ($userdetls as $key => $value) {
                             if($value->credit_amount!=null)
                             {
                             if($value->credit_amount!=null)
                             {
                                $us = AccountingDetails::find()->where(['transaction_id'=>'J'.$data->id])->andWhere(['accounting_type'=>'Credit'])->one();
                                 return $us->ledgerhead_id;
                                //  return $value->account_id;
                             }
                             }
                         }
                        }
                     ],
                     [
                         'label'=>'Total Amount',
                        'attribute' => 'total_credit',
                        'value' => function ($data) {
                         return $data->total_credit;
                        }
                     ],

            //'totalamt',
            'prefix',
            'suffix',
            'notes',
            'ref_no',
              [
                'attribute'=>'document_name',
                'label'=>'Document Name',
                'format' => 'raw',
                'value' => function ($model, $key, $index, $widget) {
                    if($model->document_name)
                    return "=HYPERLINK(\"" . Url::base(true) .'/usersdocument/accounting_journal/'.$model->document_name. "\", \"" . Yii::t('app', $model->document_name) . "\")";
                }
            ],
            'created_at:date',
            'updated_at:date',
        ],
    ]);
        }else{
            $exporter = new Spreadsheet([
                'dataProvider' => $dataProvider,
                'columns' => [
                    [
                        'label'=>'Journal #',
                       'attribute' => 'jv_no',
                       'value' => function ($data) {
                        return $data->jv_no;
                       }
                    ],
                    'date:date',
                    [
                        'label'=>'Credit Account',
                       'attribute' => 'total_credit',
                       'value' => function ($data) {
                        return $data->total_credit;
                       }
                    ],
                    [
                        'label'=>'Debit Account',
                       'attribute' => 'total_debit',
                       'value' => function ($data) {
                        return $data->total_debit;
                       }
                    ],

		     [
                        'label'=>'From',
                        'value' => function ($data) {
                         $userdetls = JournalDebitCredit::find()->where(['journal_id'=>$data->id])->all();
                         foreach ($userdetls as $key => $value) {
                             if($value->debit_amount!=null)
                             {
                             if($value->debit_amount!=null)
                             {
                                 $us = AccountingDetails::find()->where(['transaction_id'=>'J'.$data->id])->andWhere(['accounting_type'=>'Debit'])->one();
                                 return $us->ledgerhead_id;
                             }
                             }
                         }
                        }
                     ],
                     [
                         'label'=>'To',
                        'value' => function ($data) {
                         $userdetls = JournalDebitCredit::find()->where(['journal_id'=>$data->id])->all();
                         foreach ($userdetls as $key => $value) {
                             if($value->credit_amount!=null)
                             {
                             if($value->credit_amount!=null)
                             {
                                $us = AccountingDetails::find()->where(['transaction_id'=>'J'.$data->id])->andWhere(['accounting_type'=>'Credit'])->one();
                                 return $us->ledgerhead_id;
                                //  return $value->account_id;
                             }
                             }
                         }
                        }
                     ],
                     [
                         'label'=>'Total Amount',
                        'attribute' => 'total_credit',
                        'value' => function ($data) {
                         return $data->total_credit;
                        }
                     ],

                   // 'totalamt',
                    
                ],
            ]);
        }
    if($detail)
    return $exporter->send('accounting_journal_details.xlsx');
    return $exporter->send('accounting_journal.xlsx');
    }
    public function actionJournalTemplate($id=null,$from=null)
    { 
        if($from=='all')
        {
            $dataProvider = new ActiveDataProvider([
            'query' => AccountingJournal::find()->where(['is_deleted'=>0])->orderBy(['id' => SORT_DESC]),
            ]);
            $dataProvider->pagination = false;
            $mpdf = new mPDF;
            $mpdf->WriteHTML($this->renderPartial('exportpdf', [
                'dataProvider' => $dataProvider,

            ]));
            $mpdf->Output('accounting_journal.pdf', 'I');
        }
        else
        {
              $model = $this->findModel($id);
              $accountids=JournalDebitCredit::find()->all();
              $mpdf = new mPDF;
              $mpdf->showImageErrors = true;
              $mpdf->WriteHTML($this->renderPartial('/accounting-journal/journal-template', [
                    'model' => $model,
                    'accountids'=>$accountids,
                ]));

              $mpdf->Output('journal-template.pdf', 'I');
        }
    }
    public function actionGetAccount()
    {
        Yii::$app->view->params['active']=105;
        $account=AccountingLedger::find()->all();
        $accountlist=ArrayHelper::map($account, 'accounting_ledger_id', 'name');
        $accountlist=[];
        foreach($account as $value){
            $group=GroupName::find()->where(['group_name_id'=>$value->group_name_id])->one();
            $accountlist[$group['name_group']][$value->accounting_ledger_id]=$value->name;
        }
        print_r(json_encode($accountlist));die();
        return json_encode($accountlist);
    }
    public function actionGetDescription()
    {
        Yii::$app->view->params['active']=105;
        $account=AccountingLedger::find()->where(['id'=>Yii::$app->request->post('data')])->one();
        return json_encode([
            'debit'=>$account,
            'credit'=>$account,
            ]);
    }
    /**
     * Deletes an existing AccountingJournal model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    /**
     * Finds the AccountingJournal model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return AccountingJournal the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = AccountingJournal::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }

    public function actionFindbill($user_id)
    {

        $find_ledger_user = AccountingLedger::find()->where(['accounting_ledger_id' => $user_id])->one();

        if ($find_ledger_user->group_name_id == '28' && $find_ledger_user->account_type_id == '4') {
            $find_customer = Customer::find()->where(['business_name' => $find_ledger_user->ledger_id])->one();
            $inv = Invoice::find()->select('id AS id,invoice_id AS invoice_id,total_price AS total_price,due_date AS due_date,pending_amount AS pending_amount')->where(['customer_name' => $find_customer->id])->asArray()->all();
        }

        if ($find_ledger_user->group_name_id == '29' && $find_ledger_user->account_type_id == '3') {

            $find_vendor = Vendor::find()->where(['business_name' => $find_ledger_user->ledger_id])->one();
            $inv = PurchaseBill::find()->select('id AS id,full_bill_name AS invoice_id,total AS total_price,due_date AS due_date,pending_amount AS pending_amount')->where(['vendor_id' => $find_vendor->id])->asArray()->all();
        }


        return json_encode($inv);
    }

    public function actionFinduser($user_id)
    {

        $find_ledger_user = AccountingLedger::find()->where(['accounting_ledger_id' => $user_id])->asArray()->one();
        // print_r($find_ledger_user);die();
        return json_encode($find_ledger_user);
    }
}
