<?php

namespace backend\modules\users\models;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\users\models\CreditNote;
use backend\models\UserClient;
use backend\modules\master\models\Customer;


/**
 * CreditNoteSearch represents the model behind the search form of `backend\modules\users\models\CreditNote`.
 */
class CreditNoteSearch extends CreditNote
{
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id', 'match_invoice', 'show_to_store_keeper', 'is_deleted'], 'integer'],
            [['setting_type', 'customer_name', 'notes', 'receiver_gstn', 'sales_type', 'supply_type', 'supply_reverse_charge', 'pricelist', 'point_of_supply', 'is_invoice_paid_provisional', 'prefix', 'credit_note_no', 'suffix', 'credit_note_id', 'date', 'invoice_no', 'invoice_date', 'order_type', 'credit_note_terms', 'credit_notes', 'created_at', 'updated_at'], 'safe'],
            [['sub_total_amount', 'total_amount'], 'number'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params,array $accessed=null)
    {
        if($accessed == null)
        {
           $query = CreditNote::find()->where(['is_deleted'=>0])->orderBy(['id' => SORT_DESC]);
        }
        else
        {
            $customers = UserClient::find()->where(['user_id'=>$accessed])->all();
            $customer_ids = [];
            $j = 0;
            foreach($customers as $data)
            {
                $customer_ids[$j] = $data->client_id;
                $j++;
            }
            $query = CreditNote::find()->where(['is_deleted'=>0])->andWhere(['in', 'customer_name', $customer_ids])->orderBy(['id' => SORT_DESC]);
        }







        // $query = CreditNote::find()->where(['is_deleted'=>0])->orderBy(['id' => SORT_DESC]);

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id' => $this->id,
            'date' => $this->date,
            'invoice_date' => $this->invoice_date,
            'sub_total_amount' => $this->sub_total_amount,
            'total_amount' => $this->total_amount,
            'match_invoice' => $this->match_invoice,
            'show_to_store_keeper' => $this->show_to_store_keeper,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
            'is_deleted' => $this->is_deleted,
        ]);

        $query->andFilterWhere(['like', 'setting_type', $this->setting_type])
            ->andFilterWhere(['like', 'customer_name', $this->customer_name])
            ->andFilterWhere(['like', 'notes', $this->notes])
            ->andFilterWhere(['like', 'receiver_gstn', $this->receiver_gstn])
            ->andFilterWhere(['like', 'sales_type', $this->sales_type])
            ->andFilterWhere(['like', 'supply_type', $this->supply_type])
            ->andFilterWhere(['like', 'supply_reverse_charge', $this->supply_reverse_charge])
            ->andFilterWhere(['like', 'pricelist', $this->pricelist])
            ->andFilterWhere(['like', 'point_of_supply', $this->point_of_supply])
            ->andFilterWhere(['like', 'is_invoice_paid_provisional', $this->is_invoice_paid_provisional])
            ->andFilterWhere(['like', 'prefix', $this->prefix])
            ->andFilterWhere(['like', 'credit_note_no', $this->credit_note_no])
            ->andFilterWhere(['like', 'suffix', $this->suffix])
            ->andFilterWhere(['like', 'credit_note_id', $this->credit_note_id])
            ->andFilterWhere(['like', 'invoice_no', $this->invoice_no])
            ->andFilterWhere(['like', 'order_type', $this->order_type])
            ->andFilterWhere(['like', 'credit_note_terms', $this->credit_note_terms])
            ->andFilterWhere(['like', 'credit_notes', $this->credit_notes]);

        return $dataProvider;
    }
}
