<?php

namespace backend\modules\users\models;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\users\models\ProductDelivered;
use backend\modules\master\models\Customer;
use backend\models\UserClient;
/**
 * ProductDeliveredSearch represents the model behind the search form of `backend\modules\users\models\ProductDelivered`.
 */
class ProductDeliveredSearch extends ProductDelivered
{
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id', 'dispatch_details', 'deliver_to', 'request_invoice'], 'integer'],
            [['customer_id','setting_id', 'date', 'remarks', 'prefix', 'dc_no', 'suffix', 'notes', 'terms', 'product_code', 'dispatch_doc_no', 'dispatch_date', 'dispatched_through', 'destination', 'terms_of_delivery', 'company', 'name', 'address_1', 'address_2', 'city', 'state', 'zip_code', 'created_at', 'updated_at'], 'safe'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params, array $accessed=null)
    {

        if($accessed == null)
        {
            $query = ProductDelivered::find()->where(['is_deleted'=>0])->orderBy(['id'=>SORT_DESC]);
        }
        else
        {
                $check_id = Yii::$app->user->identity->id;

                $customers = UserClient::find()->where(['user_id'=>$check_id])->andWhere(['client_type'=>'Customer'])->all();
                $customer_ids = [];
                $j = 0;
                foreach($customers as $data)
                {
                    $customer_ids[$j] = $data->client_id;
                    $j++;
                }
                $query = ProductDelivered::find()->where(['is_deleted'=>0])->andWhere(['in', 'customer_id', $customer_ids])->orderBy(['id' => SORT_DESC]);
        }

        // $query = ProductDelivered::find()->where(['is_deleted'=>0])->orderBy(['id'=>SORT_DESC]);

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id' => $this->id,
            // 'customer_id' => $this->customer_id,
            'dispatch_details' => $this->dispatch_details,
            'deliver_to' => $this->deliver_to,
            'request_invoice' => $this->request_invoice,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ]);

        $query->andFilterWhere(['like', 'setting_id', $this->setting_id])
            ->andFilterWhere(['like', 'date', $this->date])
            ->andFilterWhere(['like', 'remarks', $this->remarks])
            ->andFilterWhere(['like', 'prefix', $this->prefix])
            ->andFilterWhere(['like', 'dc_no', $this->dc_no])
            ->andFilterWhere(['like', 'suffix', $this->suffix])
            ->andFilterWhere(['like', 'notes', $this->notes])
            ->andFilterWhere(['like', 'terms', $this->terms])
            ->andFilterWhere(['like', 'product_code', $this->product_code])
            ->andFilterWhere(['like', 'dispatch_doc_no', $this->dispatch_doc_no])
            ->andFilterWhere(['like', 'dispatch_date', $this->dispatch_date])
            ->andFilterWhere(['like', 'dispatched_through', $this->dispatched_through])
            ->andFilterWhere(['like', 'destination', $this->destination])
            ->andFilterWhere(['like', 'terms_of_delivery', $this->terms_of_delivery])
            ->andFilterWhere(['like', 'company', $this->company])
            ->andFilterWhere(['like', 'name', $this->name])
            ->andFilterWhere(['like', 'address_1', $this->address_1])
            ->andFilterWhere(['like', 'address_2', $this->address_2])
            ->andFilterWhere(['like', 'city', $this->city])
            ->andFilterWhere(['like', 'state', $this->state])
            ->andFilterWhere(['like', 'zip_code', $this->zip_code]);
            if($this->customer_id){
                $customer=Customer::find()->select('id')->where(['like','business_name',$this->customer_id])->column();
                $query->andFilterWhere(['in', 'customer_id', $customer]);
            }

        return $dataProvider;
    }
}
