<?php

namespace backend\modules\users\models;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\modules\users\models\ProductReceived;
use backend\modules\master\models\Vendor;
use backend\models\UserClient;

/**
 * ProductReceivedSearch represents the model behind the search form of `backend\modules\users\models\ProductReceived`.
 */
class ProductReceivedSearch extends ProductReceived
{
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id', 'vendor_id'], 'integer'],
            [['setting_id', 'date', 'prefix', 'shippment_no', 'suffix', 'notes', 'income_terms', 'product_code', 'created_at', 'updated_at'], 'safe'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params, array $accessed=null)
    {

        if($accessed == null)
        {
            $query = ProductReceived::find()->where(['is_deleted'=>0])->orderBy(['id'=>SORT_DESC]);
        }
        else
        {
            $check_id = Yii::$app->user->identity->id;

            $customers = UserClient::find()->where(['user_id'=>$check_id])->andWhere(['client_type'=>'Vendor'])->all();
            $customer_ids = [];
            $j = 0;
            foreach($customers as $data)
            {
                $customer_ids[$j] = $data->client_id;
                $j++;
            }
            $query = ProductReceived::find()->where(['is_deleted'=>0])->andWhere(['in', 'vendor_id', $customer_ids])->orderBy(['id' => SORT_DESC]);
        }

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id' => $this->id,
            'vendor_id' => $this->vendor_id,
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ]);

        $query->andFilterWhere(['like', 'setting_id', $this->setting_id])
            ->andFilterWhere(['like', 'date', $this->date])
            ->andFilterWhere(['like', 'prefix', $this->prefix])
            ->andFilterWhere(['like', 'shippment_no', $this->shippment_no])
            ->andFilterWhere(['like', 'suffix', $this->suffix])
            ->andFilterWhere(['like', 'notes', $this->notes])
            ->andFilterWhere(['like', 'income_terms', $this->income_terms])
            ->andFilterWhere(['like', 'product_code', $this->product_code]);

        return $dataProvider;
    }
}
