<?php

namespace backend\modules\users\models;

use Yii;

/**
 * This is the model class for table "receipt_details".
 *
 * @property int $id
 * @property string $setting_type
 * @property string $payment_type
 * @property string $receipt_no
 * @property string $receipt_date
 * @property string $cheque_no
 * @property string $cheque_date
 * @property string $payment_mode
 * @property string $bank_name
 * @property string $amount
 * @property string $tds_amount
 * @property string $customer_name
 * @property string $receipt_documents
 * @property string $notes
 * @property string $created_at
 * @property string $updated_at
 */
class ReceiptDetails extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'receipt_details';
    }
     public $r_number;
    public $receipt_prifix;
    public $receipt_suffix;
    public $from_date;
    public $to_date;
    public $customer;
    public $bank;
    public $setting;
    public $type_of_payment;
    public $amount_from;
    public $amount_upto;
    public $cheque_number;
    public $receipt_note;
    public $type_of_customer;

    public $c_code;
    public $c_mobile;
    public $findid;
    public $text_send;
    public $send_email;
    public $bcc_to_email;
    public $cc_to_email;
    public $email_subject;
    public $email_message;
    public $email_attachment;

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['setting_type', 'payment_type', 'receipt_date', 'payment_mode',  'amount','tds_amount','created_at', 'updated_at'], 'required'],
            [['receipt_date', 'cheque_date','from_date','to_date','transaction_date'], 'safe'],
            [['notes','receipt_note','text_send','email_subject','email_message','findid','transaction_no','email_attachment'], 'string'],
             // [['receipt_date'], 'date','format' => 'dd-mm-yyyy'],
            [['setting_type', 'payment_type', 'cheque_no', 'payment_mode', 'bank_name',  'customer_name', 'receipt_documents','receipt_id','prefix','suffix','bank','setting','type_of_payment','customer','customer_type','type_of_customer'], 'string', 'max' => 254],
            [['receipt_no','c_code','c_mobile'], 'string', 'max' => 30],
           // [['receipt_no'],'unique','message' => 'This Receipt Number updated as previous number is already taken.'],
            // [['amount', 'tds_amount','amount_from','amount_upto','total_amount'], 'match' ,'pattern'=>'/^[0-9]+$/u', 'message'=> 'Discount Can Contain only numeric characters.'],
            ['send_email','email','message'=> 'Enter a valid Email'],
            ['bcc_to_email','email','message'=> 'Enter a valid Email'],
            ['cc_to_email','email','message'=> 'Enter a valid Email'],
            [['r_number','receipt_prifix','receipt_suffix'],'safe'],
            [['cheque_number','cheque_no'], 'match' ,'pattern'=>'/^(?!(000|666|9))\d{6}$/', 'message'=> 'Format should be XXXXXX.'],
            [['tds_amount', 'amount','total_amount','amount_from','amount_upto','invoice_amount','balance_amount'], 'number'],
            ['cheque_no', 'required', 'when' => function($model) {
                return $model->payment_mode == 'Cheque';
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-payment_mode').val() == 'Cheque';
            }"],
            ['cheque_date', 'required', 'when' => function($model) {
                return $model->payment_mode == 'Cheque';
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-payment_mode').val() == 'Cheque';
            }"],
            

	    ['transaction_no', 'required', 'when' => function($model) {
                return $model->payment_mode == 'Online Transaction';
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-payment_mode').val() == 'Online Transaction';
            }"],
            ['transaction_date', 'required', 'when' => function($model) {
                return $model->payment_mode == 'Online Transaction';
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-payment_mode').val() == 'Online Transaction';
            }"],
             ['bank_name', 'required', 'when' => function($model) {
                return $model->payment_mode == 'Online Transaction';
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-payment_mode').val() == 'Online Transaction';
            }"],


             ['cheque_no', 'unique','message' => 'This Cheque has already been used.'],
             [['receipt_date'], 'compare' ,'compareValue'=>date("Y-m-d"),'operator'=>'<=', 'message'=> 'Date cant be greated than todays date'],
             [['to_date'], 'compare' ,'compareAttribute' => 'from_date','operator'=>'>=', 'message'=> 'To Date must be equal/greater than From date'],
             ['to_date', 'required', 'when' => function($model) {
                return $model->from_date;
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-from_date').val();
            }"],
            ['from_date', 'required', 'when' => function($model) {
                return $model->to_date;
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-to_date').val();
            }"],
            ['r_number', 'required', 'when' => function($model) {
                return $model->receipt_prifix;
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-receipt_prifix').val();
            }",'message'=>'Receipt No. is required'],
            ['r_number', 'required', 'when' => function($model) {
                return $model->receipt_suffix;
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-receipt_suffix').val();
            }",'message'=>'Receipt No. is required'],
             [['amount_upto'], 'compare' ,'compareAttribute' => 'amount_from','operator'=>'>=', 'message'=> 'Amount To must be equal/greater than Amount From'],
             ['amount_upto', 'required', 'when' => function($model) {
                return $model->amount_from;
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-amount_from').val();
            }",'message'=>'Amount to is required'],
            ['amount_from', 'required', 'when' => function($model) {
                return $model->amount_upto;
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-amount_upto').val();
            }",'message'=>'Amount from is required'],

            ['bank_name', 'required', 'when' => function($model) {
                return $model->payment_mode == 'Cheque';
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-payment_mode').val() == 'Cheque';
            }"],
            ['bank_name', 'required', 'when' => function($model) {
                return $model->payment_mode == 'Card';
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-payment_mode').val() == 'Card';
            }"],
            ['bank_name', 'required', 'when' => function($model) {
                return $model->payment_mode == 'Mobile Payments';
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-payment_mode').val() == 'Mobile Payments';
            }"],
            ['customer_name', 'required', 'when' => function($model) {
                return $model->payment_type == 'Payment Against Invoice';
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-payment_type').val() == 'Payment Against Invoice';
            }"],
            ['customer_name', 'required', 'when' => function($model) {
                return $model->payment_type == 'Advance against invoice';
            },'whenClient' => "function (attribute, value) {
                return $('#receiptdetails-payment_type').val() == 'Advance against invoice';
            }"],

        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'setting_type' => 'Setting Type',
            'payment_type' => 'Payment Type',
            'receipt_no' => 'Receipt No',
            'receipt_date' => 'Receipt Date',
            'cheque_no' => 'Cheque No',
            'cheque_date' => 'Cheque Date',
            'payment_mode' => 'Payment Mode',
            'bank_name' => 'Bank Name',
            'amount' => 'Amount',
            'tds_amount' => 'Tds Amount',
            'customer_name' => 'Customer Name',
            'receipt_documents' => 'Receipt Documents',
            'notes' => 'Notes',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
        ];
    }
}
