<?php

namespace backend\modules\users\models;

use Yii;

/**
 * This is the model class for table "sale_order".
 *
 * @property int $id
 * @property int $customer_id
 * @property int $executive_id
 * @property string|null $note
 * @property string|null $receiver
 * @property string|null $sale_type
 * @property string|null $supply_type
 * @property string|null $reverse_charge
 * @property string|null $priority
 * @property string|null $price_list
 * @property string|null $po_no
 * @property string|null $po_details
 * @property string|null $point_of_supply
 * @property string|null $is_invoice_paid_provisional
 * @property string|null $po_date
 * @property string|null $po_exp_date
 * @property string|null $prefix
 * @property string|null $sale_order
 * @property string|null $suffix
 * @property string|null $sale_order_id
 * @property string|null $date
 * @property string|null $delivery_date
 * @property string|null $due_date
 * @property string|null $terms_of_payment
 * @property string|null $product_code
 * @property string|null $advance_payment
 * @property string|null $receipt_id
 * @property string|null $set_reminder
 * @property string|null $show_to_store_keeper
 * @property string|null $full_order_product_wise
 * @property string|null $other_note
 * @property string|null $terms
 * @property string $created_at
 * @property string $updated_at
 */
class SaleOrder extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'sale_order';
    }
    public $from_date;
    public $to_date;
    public $customer;
    // public $setting;
    // public $total_amount;
    public $executives_name;
    public $delv_date;
    public $receipt_payment_mode;
    public $sale_total_amount;
    public $commonsearch;
    public $saleorder_status;
    public $searchproduct;
    public $findid; 
    public $type_inventory;
    public $ref;

    public $c_code;
    public $c_mobile;
    public $text_send;
    public $send_email;
    public $bcc_to_email;
    public $cc_to_email;
    public $email_subject;
    public $email_message;
    public $mail_id;
    public $email_attachment;

  
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['customer_id','date'], 'required'],
            [['setting_type'], 'required'],
            [['customer_id', 'executive_id','is_cancel','dc_status'], 'integer'],
            [['note', 'other_note', 'terms','advance_note','cancel_reason','text_send','email_message','email_attachment'], 'string'],
            [['created_at', 'updated_at','from_date','to_date','delv_date','receipt_cheque_date','date', 'delivery_date', 'due_date', 'po_date', 'po_exp_date'], 'safe'],
            [['receiver', 'sale_type', 'reverse_charge', 'priority', 'price_list', 'point_of_supply', 'is_invoice_paid_provisional', 'prefix', 'sale_order', 'suffix', 'terms_of_payment', 'full_order_product_wise','customer','executives_name','receipt_setting_type','receipt_bank','receipt_payment_mode','receipt_cheque_no','saleorder_source','converted_to','saleorder_status','findid','is_tcs','mail_id'], 'string', 'max' => 32],
            [['supply_type','searchproduct','lead_quote_id','ref','c_code','c_mobile'], 'string', 'max' => 64],
            [['po_details','po_no'], 'string', 'max' => 512],
            [['sale_order_id', 'advance_payment', 'receipt_id','avl_status','type_inventory','commonsearch','email_subject'], 'string', 'max' => 254],
            [['product_code'], 'string', 'max' => 128],
            [['set_reminder', 'show_to_store_keeper'], 'string', 'max' => 8],
            ['send_email','email','message'=> 'Enter a valid Email'],
            ['bcc_to_email','email','message'=> 'Enter a valid Email'],
            ['cc_to_email','email','message'=> 'Enter a valid Email'],
            [['sub_total_amount', 'total_amount','sale_total_amount','receipt_total_amount','igst_amount','cgst_amount','sgst_amount','tcs_amount','amount'], 'number'],
            [['receiver'], 'string','min'=>15, 'max' => 15],
             [['receiver'], 'match' ,'pattern'=>'/^([0-9]){2}([A-Z]){4}([0-9A-Z]){1}([0-9]){4}([A-Z]){1}([0-9A-Z]){1}([0-9A-Z]){1}([0-9A-Z]){1}?$/', 'message'=> 'GSTN Format should be like  12ABCDE1234Z1Z1.'],
             [['delivery_date'], 'compare' ,'compareValue'=>date("Y-m-d"),'operator'=>'>=', 'message'=> 'Delivery Date must be equal/greater than todays date'],
             // [['due_date'], 'compare' ,'compareValue'=>date("Y-m-d"),'operator'=>'>=', 'message'=> 'Due Date must be equal/greater than todays date'],
            [['sale_order'],'unique','message' => 'This Sale Order No updated as previous number is already taken.'],
             ['po_exp_date', 'compare', 'compareAttribute' => 'po_date', 'operator' => '>'],
           // [['receipt_cheque_no'], 'match' ,'pattern'=>'/^(?!(000|666|9))\d{4}-(?!00)\d{4}-(?!0000)\d{4}$/', 'message'=> 'Format should be XXXX-XXXX-XXXX.'],
             [['receipt_cheque_no'], 'string', 'max' => 6],
            [['to_date'], 'compare' ,'compareAttribute' => 'from_date','operator'=>'>=', 'message'=> 'To Date must be equal/greater than From date'],
             ['to_date', 'required', 'when' => function($model) {
                return $model->from_date;
            },'whenClient' => "function (attribute, value) {
                return $('#saleorder-from_date').val();
            }"],
            ['from_date', 'required', 'when' => function($model) {
                return $model->to_date;
            },'whenClient' => "function (attribute, value) {
                return $('#saleorder-to_date').val();
            }"],
            
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'customer_id' => 'Customer ID',
            'executive_id' => 'Executive ID',
            'note' => 'Note',
            'receiver' => 'Receiver',
            'sale_type' => 'Sale Type',
            'supply_type' => 'Supply Type',
            'reverse_charge' => 'Reverse Charge',
            'priority' => 'Priority',
            'price_list' => 'Price List',
            'po_no' => 'Po No',
            'po_details' => 'Po Details',
            'point_of_supply' => 'Point Of Supply',
            'is_invoice_paid_provisional' => 'Is Invoice Paid Provisional',
            'po_date' => 'Po Date',
            'po_exp_date' => 'Po Exp Date',
            'prefix' => 'Prefix',
            'sale_order' => 'Sale Order',
            'suffix' => 'Suffix',
            'sale_order_id' => 'Sale Order ID',
            'date' => 'Date',
            'delivery_date' => 'Delivery Date',
            'due_date' => 'Due Date',
            'terms_of_payment' => 'Terms Of Payment',
            'product_code' => 'Product Code',
            'advance_payment' => 'Advance Payment',
            'receipt_id' => 'Receipt ID',
            'set_reminder' => 'Set Reminder',
            'show_to_store_keeper' => 'Show To Store Keeper',
            'full_order_product_wise' => 'Full Order Product Wise',
            'other_note' => 'Other Note',
            'terms' => 'Terms',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
        ];
    }
}
